"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ContainerAnalysisNoteXAttestationAuthorityXHint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HUMAN_READABLE_NAME_FIELD_NUMBER: builtins.int
    human_readable_name: builtins.str
    def __init__(
        self,
        *,
        human_readable_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["human_readable_name", b"human_readable_name"]) -> None: ...

global___ContainerAnalysisNoteXAttestationAuthorityXHint = ContainerAnalysisNoteXAttestationAuthorityXHint

@typing_extensions.final
class ContainerAnalysisNoteXAttestationAuthority(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HINT_FIELD_NUMBER: builtins.int
    @property
    def hint(self) -> global___ContainerAnalysisNoteXAttestationAuthorityXHint: ...
    def __init__(
        self,
        *,
        hint: global___ContainerAnalysisNoteXAttestationAuthorityXHint | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hint", b"hint"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hint", b"hint"]) -> None: ...

global___ContainerAnalysisNoteXAttestationAuthority = ContainerAnalysisNoteXAttestationAuthority

@typing_extensions.final
class ContainerAnalysisNoteXRelatedUrl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    label: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        label: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["label", b"label", "url", b"url"]) -> None: ...

global___ContainerAnalysisNoteXRelatedUrl = ContainerAnalysisNoteXRelatedUrl

@typing_extensions.final
class ContainerAnalysisNoteXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ContainerAnalysisNoteXTimeouts = ContainerAnalysisNoteXTimeouts

@typing_extensions.final
class ContainerAnalysisNote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LONG_DESCRIPTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RELATED_NOTE_NAMES_FIELD_NUMBER: builtins.int
    SHORT_DESCRIPTION_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    ATTESTATION_AUTHORITY_FIELD_NUMBER: builtins.int
    RELATED_URL_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    expiration_time: builtins.str
    id: builtins.str
    kind: builtins.str
    long_description: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def related_note_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    short_description: builtins.str
    update_time: builtins.str
    @property
    def attestation_authority(self) -> global___ContainerAnalysisNoteXAttestationAuthority: ...
    @property
    def related_url(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerAnalysisNoteXRelatedUrl]: ...
    @property
    def timeouts(self) -> global___ContainerAnalysisNoteXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        expiration_time: builtins.str = ...,
        id: builtins.str = ...,
        kind: builtins.str = ...,
        long_description: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        related_note_names: collections.abc.Iterable[builtins.str] | None = ...,
        short_description: builtins.str = ...,
        update_time: builtins.str = ...,
        attestation_authority: global___ContainerAnalysisNoteXAttestationAuthority | None = ...,
        related_url: collections.abc.Iterable[global___ContainerAnalysisNoteXRelatedUrl] | None = ...,
        timeouts: global___ContainerAnalysisNoteXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attestation_authority", b"attestation_authority", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attestation_authority", b"attestation_authority", "create_time", b"create_time", "expiration_time", b"expiration_time", "id", b"id", "kind", b"kind", "long_description", b"long_description", "name", b"name", "project", b"project", "related_note_names", b"related_note_names", "related_url", b"related_url", "resource_info", b"resource_info", "short_description", b"short_description", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___ContainerAnalysisNote = ContainerAnalysisNote

@typing_extensions.final
class ContainerAnalysisOccurrenceXAttestationXSignatures(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLIC_KEY_ID_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    public_key_id: builtins.str
    signature: builtins.str
    def __init__(
        self,
        *,
        public_key_id: builtins.str = ...,
        signature: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["public_key_id", b"public_key_id", "signature", b"signature"]) -> None: ...

global___ContainerAnalysisOccurrenceXAttestationXSignatures = ContainerAnalysisOccurrenceXAttestationXSignatures

@typing_extensions.final
class ContainerAnalysisOccurrenceXAttestation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERIALIZED_PAYLOAD_FIELD_NUMBER: builtins.int
    SIGNATURES_FIELD_NUMBER: builtins.int
    serialized_payload: builtins.str
    @property
    def signatures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerAnalysisOccurrenceXAttestationXSignatures]: ...
    def __init__(
        self,
        *,
        serialized_payload: builtins.str = ...,
        signatures: collections.abc.Iterable[global___ContainerAnalysisOccurrenceXAttestationXSignatures] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["serialized_payload", b"serialized_payload", "signatures", b"signatures"]) -> None: ...

global___ContainerAnalysisOccurrenceXAttestation = ContainerAnalysisOccurrenceXAttestation

@typing_extensions.final
class ContainerAnalysisOccurrenceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ContainerAnalysisOccurrenceXTimeouts = ContainerAnalysisOccurrenceXTimeouts

@typing_extensions.final
class ContainerAnalysisOccurrence(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NOTE_NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REMEDIATION_FIELD_NUMBER: builtins.int
    RESOURCE_URI_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    ATTESTATION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    id: builtins.str
    kind: builtins.str
    name: builtins.str
    note_name: builtins.str
    project: builtins.str
    remediation: builtins.str
    resource_uri: builtins.str
    update_time: builtins.str
    @property
    def attestation(self) -> global___ContainerAnalysisOccurrenceXAttestation: ...
    @property
    def timeouts(self) -> global___ContainerAnalysisOccurrenceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        id: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        note_name: builtins.str = ...,
        project: builtins.str = ...,
        remediation: builtins.str = ...,
        resource_uri: builtins.str = ...,
        update_time: builtins.str = ...,
        attestation: global___ContainerAnalysisOccurrenceXAttestation | None = ...,
        timeouts: global___ContainerAnalysisOccurrenceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attestation", b"attestation", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attestation", b"attestation", "create_time", b"create_time", "id", b"id", "kind", b"kind", "name", b"name", "note_name", b"note_name", "project", b"project", "remediation", b"remediation", "resource_info", b"resource_info", "resource_uri", b"resource_uri", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___ContainerAnalysisOccurrence = ContainerAnalysisOccurrence

@typing_extensions.final
class ContainerAwsClusterXAuthorizationXAdminUsers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    username: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["username", b"username"]) -> None: ...

global___ContainerAwsClusterXAuthorizationXAdminUsers = ContainerAwsClusterXAuthorizationXAdminUsers

@typing_extensions.final
class ContainerAwsClusterXAuthorization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMIN_USERS_FIELD_NUMBER: builtins.int
    @property
    def admin_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerAwsClusterXAuthorizationXAdminUsers]: ...
    def __init__(
        self,
        *,
        admin_users: collections.abc.Iterable[global___ContainerAwsClusterXAuthorizationXAdminUsers] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_users", b"admin_users"]) -> None: ...

global___ContainerAwsClusterXAuthorization = ContainerAwsClusterXAuthorization

@typing_extensions.final
class ContainerAwsClusterXControlPlaneXAwsServicesAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_ARN_FIELD_NUMBER: builtins.int
    ROLE_SESSION_NAME_FIELD_NUMBER: builtins.int
    role_arn: builtins.str
    role_session_name: builtins.str
    def __init__(
        self,
        *,
        role_arn: builtins.str = ...,
        role_session_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["role_arn", b"role_arn", "role_session_name", b"role_session_name"]) -> None: ...

global___ContainerAwsClusterXControlPlaneXAwsServicesAuthentication = ContainerAwsClusterXControlPlaneXAwsServicesAuthentication

@typing_extensions.final
class ContainerAwsClusterXControlPlaneXConfigEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    kms_key_arn: builtins.str
    def __init__(
        self,
        *,
        kms_key_arn: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_arn", b"kms_key_arn"]) -> None: ...

global___ContainerAwsClusterXControlPlaneXConfigEncryption = ContainerAwsClusterXControlPlaneXConfigEncryption

@typing_extensions.final
class ContainerAwsClusterXControlPlaneXDatabaseEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    kms_key_arn: builtins.str
    def __init__(
        self,
        *,
        kms_key_arn: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_arn", b"kms_key_arn"]) -> None: ...

global___ContainerAwsClusterXControlPlaneXDatabaseEncryption = ContainerAwsClusterXControlPlaneXDatabaseEncryption

@typing_extensions.final
class ContainerAwsClusterXControlPlaneXMainVolume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IOPS_FIELD_NUMBER: builtins.int
    KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    SIZE_GIB_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    iops: builtins.float
    kms_key_arn: builtins.str
    size_gib: builtins.float
    volume_type: builtins.str
    def __init__(
        self,
        *,
        iops: builtins.float = ...,
        kms_key_arn: builtins.str = ...,
        size_gib: builtins.float = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["iops", b"iops", "kms_key_arn", b"kms_key_arn", "size_gib", b"size_gib", "volume_type", b"volume_type"]) -> None: ...

global___ContainerAwsClusterXControlPlaneXMainVolume = ContainerAwsClusterXControlPlaneXMainVolume

@typing_extensions.final
class ContainerAwsClusterXControlPlaneXProxyConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ARN_FIELD_NUMBER: builtins.int
    SECRET_VERSION_FIELD_NUMBER: builtins.int
    secret_arn: builtins.str
    secret_version: builtins.str
    def __init__(
        self,
        *,
        secret_arn: builtins.str = ...,
        secret_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_arn", b"secret_arn", "secret_version", b"secret_version"]) -> None: ...

global___ContainerAwsClusterXControlPlaneXProxyConfig = ContainerAwsClusterXControlPlaneXProxyConfig

@typing_extensions.final
class ContainerAwsClusterXControlPlaneXRootVolume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IOPS_FIELD_NUMBER: builtins.int
    KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    SIZE_GIB_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    iops: builtins.float
    kms_key_arn: builtins.str
    size_gib: builtins.float
    volume_type: builtins.str
    def __init__(
        self,
        *,
        iops: builtins.float = ...,
        kms_key_arn: builtins.str = ...,
        size_gib: builtins.float = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["iops", b"iops", "kms_key_arn", b"kms_key_arn", "size_gib", b"size_gib", "volume_type", b"volume_type"]) -> None: ...

global___ContainerAwsClusterXControlPlaneXRootVolume = ContainerAwsClusterXControlPlaneXRootVolume

@typing_extensions.final
class ContainerAwsClusterXControlPlaneXSshConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EC2_KEY_PAIR_FIELD_NUMBER: builtins.int
    ec2_key_pair: builtins.str
    def __init__(
        self,
        *,
        ec2_key_pair: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ec2_key_pair", b"ec2_key_pair"]) -> None: ...

global___ContainerAwsClusterXControlPlaneXSshConfig = ContainerAwsClusterXControlPlaneXSshConfig

@typing_extensions.final
class ContainerAwsClusterXControlPlane(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    IAM_INSTANCE_PROFILE_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    AWS_SERVICES_AUTHENTICATION_FIELD_NUMBER: builtins.int
    CONFIG_ENCRYPTION_FIELD_NUMBER: builtins.int
    DATABASE_ENCRYPTION_FIELD_NUMBER: builtins.int
    MAIN_VOLUME_FIELD_NUMBER: builtins.int
    PROXY_CONFIG_FIELD_NUMBER: builtins.int
    ROOT_VOLUME_FIELD_NUMBER: builtins.int
    SSH_CONFIG_FIELD_NUMBER: builtins.int
    iam_instance_profile: builtins.str
    instance_type: builtins.str
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    version: builtins.str
    @property
    def aws_services_authentication(self) -> global___ContainerAwsClusterXControlPlaneXAwsServicesAuthentication: ...
    @property
    def config_encryption(self) -> global___ContainerAwsClusterXControlPlaneXConfigEncryption: ...
    @property
    def database_encryption(self) -> global___ContainerAwsClusterXControlPlaneXDatabaseEncryption: ...
    @property
    def main_volume(self) -> global___ContainerAwsClusterXControlPlaneXMainVolume: ...
    @property
    def proxy_config(self) -> global___ContainerAwsClusterXControlPlaneXProxyConfig: ...
    @property
    def root_volume(self) -> global___ContainerAwsClusterXControlPlaneXRootVolume: ...
    @property
    def ssh_config(self) -> global___ContainerAwsClusterXControlPlaneXSshConfig: ...
    def __init__(
        self,
        *,
        iam_instance_profile: builtins.str = ...,
        instance_type: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        version: builtins.str = ...,
        aws_services_authentication: global___ContainerAwsClusterXControlPlaneXAwsServicesAuthentication | None = ...,
        config_encryption: global___ContainerAwsClusterXControlPlaneXConfigEncryption | None = ...,
        database_encryption: global___ContainerAwsClusterXControlPlaneXDatabaseEncryption | None = ...,
        main_volume: global___ContainerAwsClusterXControlPlaneXMainVolume | None = ...,
        proxy_config: global___ContainerAwsClusterXControlPlaneXProxyConfig | None = ...,
        root_volume: global___ContainerAwsClusterXControlPlaneXRootVolume | None = ...,
        ssh_config: global___ContainerAwsClusterXControlPlaneXSshConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_services_authentication", b"aws_services_authentication", "config_encryption", b"config_encryption", "database_encryption", b"database_encryption", "main_volume", b"main_volume", "proxy_config", b"proxy_config", "root_volume", b"root_volume", "ssh_config", b"ssh_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_services_authentication", b"aws_services_authentication", "config_encryption", b"config_encryption", "database_encryption", b"database_encryption", "iam_instance_profile", b"iam_instance_profile", "instance_type", b"instance_type", "main_volume", b"main_volume", "proxy_config", b"proxy_config", "root_volume", b"root_volume", "security_group_ids", b"security_group_ids", "ssh_config", b"ssh_config", "subnet_ids", b"subnet_ids", "tags", b"tags", "version", b"version"]) -> None: ...

global___ContainerAwsClusterXControlPlane = ContainerAwsClusterXControlPlane

@typing_extensions.final
class ContainerAwsClusterXFleet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMBERSHIP_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    membership: builtins.str
    project: builtins.str
    def __init__(
        self,
        *,
        membership: builtins.str = ...,
        project: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["membership", b"membership", "project", b"project"]) -> None: ...

global___ContainerAwsClusterXFleet = ContainerAwsClusterXFleet

@typing_extensions.final
class ContainerAwsClusterXNetworking(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POD_ADDRESS_CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    SERVICE_ADDRESS_CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    @property
    def pod_address_cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def service_address_cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    vpc_id: builtins.str
    def __init__(
        self,
        *,
        pod_address_cidr_blocks: collections.abc.Iterable[builtins.str] | None = ...,
        service_address_cidr_blocks: collections.abc.Iterable[builtins.str] | None = ...,
        vpc_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pod_address_cidr_blocks", b"pod_address_cidr_blocks", "service_address_cidr_blocks", b"service_address_cidr_blocks", "vpc_id", b"vpc_id"]) -> None: ...

global___ContainerAwsClusterXNetworking = ContainerAwsClusterXNetworking

@typing_extensions.final
class ContainerAwsClusterXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ContainerAwsClusterXTimeouts = ContainerAwsClusterXTimeouts

@typing_extensions.final
class ContainerAwsCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class WorkloadIdentityConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANNOTATIONS_FIELD_NUMBER: builtins.int
    AWS_REGION_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RECONCILING_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    WORKLOAD_IDENTITY_CONFIG_FIELD_NUMBER: builtins.int
    AUTHORIZATION_FIELD_NUMBER: builtins.int
    CONTROL_PLANE_FIELD_NUMBER: builtins.int
    FLEET_FIELD_NUMBER: builtins.int
    NETWORKING_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    aws_region: builtins.str
    create_time: builtins.str
    description: builtins.str
    endpoint: builtins.str
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    reconciling: builtins.bool
    state: builtins.str
    uid: builtins.str
    update_time: builtins.str
    @property
    def workload_identity_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def authorization(self) -> global___ContainerAwsClusterXAuthorization: ...
    @property
    def control_plane(self) -> global___ContainerAwsClusterXControlPlane: ...
    @property
    def fleet(self) -> global___ContainerAwsClusterXFleet: ...
    @property
    def networking(self) -> global___ContainerAwsClusterXNetworking: ...
    @property
    def timeouts(self) -> global___ContainerAwsClusterXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        aws_region: builtins.str = ...,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        endpoint: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        reconciling: builtins.bool = ...,
        state: builtins.str = ...,
        uid: builtins.str = ...,
        update_time: builtins.str = ...,
        workload_identity_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        authorization: global___ContainerAwsClusterXAuthorization | None = ...,
        control_plane: global___ContainerAwsClusterXControlPlane | None = ...,
        fleet: global___ContainerAwsClusterXFleet | None = ...,
        networking: global___ContainerAwsClusterXNetworking | None = ...,
        timeouts: global___ContainerAwsClusterXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authorization", b"authorization", "control_plane", b"control_plane", "fleet", b"fleet", "networking", b"networking", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "authorization", b"authorization", "aws_region", b"aws_region", "control_plane", b"control_plane", "create_time", b"create_time", "description", b"description", "endpoint", b"endpoint", "etag", b"etag", "fleet", b"fleet", "id", b"id", "location", b"location", "name", b"name", "networking", b"networking", "project", b"project", "reconciling", b"reconciling", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts", "uid", b"uid", "update_time", b"update_time", "workload_identity_config", b"workload_identity_config"]) -> None: ...

global___ContainerAwsCluster = ContainerAwsCluster

@typing_extensions.final
class ContainerAwsNodePoolXAutoscaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_NODE_COUNT_FIELD_NUMBER: builtins.int
    MIN_NODE_COUNT_FIELD_NUMBER: builtins.int
    max_node_count: builtins.float
    min_node_count: builtins.float
    def __init__(
        self,
        *,
        max_node_count: builtins.float = ...,
        min_node_count: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_node_count", b"max_node_count", "min_node_count", b"min_node_count"]) -> None: ...

global___ContainerAwsNodePoolXAutoscaling = ContainerAwsNodePoolXAutoscaling

@typing_extensions.final
class ContainerAwsNodePoolXConfigXConfigEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    kms_key_arn: builtins.str
    def __init__(
        self,
        *,
        kms_key_arn: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_arn", b"kms_key_arn"]) -> None: ...

global___ContainerAwsNodePoolXConfigXConfigEncryption = ContainerAwsNodePoolXConfigXConfigEncryption

@typing_extensions.final
class ContainerAwsNodePoolXConfigXProxyConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ARN_FIELD_NUMBER: builtins.int
    SECRET_VERSION_FIELD_NUMBER: builtins.int
    secret_arn: builtins.str
    secret_version: builtins.str
    def __init__(
        self,
        *,
        secret_arn: builtins.str = ...,
        secret_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_arn", b"secret_arn", "secret_version", b"secret_version"]) -> None: ...

global___ContainerAwsNodePoolXConfigXProxyConfig = ContainerAwsNodePoolXConfigXProxyConfig

@typing_extensions.final
class ContainerAwsNodePoolXConfigXRootVolume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IOPS_FIELD_NUMBER: builtins.int
    KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    SIZE_GIB_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    iops: builtins.float
    kms_key_arn: builtins.str
    size_gib: builtins.float
    volume_type: builtins.str
    def __init__(
        self,
        *,
        iops: builtins.float = ...,
        kms_key_arn: builtins.str = ...,
        size_gib: builtins.float = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["iops", b"iops", "kms_key_arn", b"kms_key_arn", "size_gib", b"size_gib", "volume_type", b"volume_type"]) -> None: ...

global___ContainerAwsNodePoolXConfigXRootVolume = ContainerAwsNodePoolXConfigXRootVolume

@typing_extensions.final
class ContainerAwsNodePoolXConfigXSshConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EC2_KEY_PAIR_FIELD_NUMBER: builtins.int
    ec2_key_pair: builtins.str
    def __init__(
        self,
        *,
        ec2_key_pair: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ec2_key_pair", b"ec2_key_pair"]) -> None: ...

global___ContainerAwsNodePoolXConfigXSshConfig = ContainerAwsNodePoolXConfigXSshConfig

@typing_extensions.final
class ContainerAwsNodePoolXConfigXTaints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECT_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    effect: builtins.str
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        effect: builtins.str = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["effect", b"effect", "key", b"key", "value", b"value"]) -> None: ...

global___ContainerAwsNodePoolXConfigXTaints = ContainerAwsNodePoolXConfigXTaints

@typing_extensions.final
class ContainerAwsNodePoolXConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    IAM_INSTANCE_PROFILE_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CONFIG_ENCRYPTION_FIELD_NUMBER: builtins.int
    PROXY_CONFIG_FIELD_NUMBER: builtins.int
    ROOT_VOLUME_FIELD_NUMBER: builtins.int
    SSH_CONFIG_FIELD_NUMBER: builtins.int
    TAINTS_FIELD_NUMBER: builtins.int
    iam_instance_profile: builtins.str
    instance_type: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def config_encryption(self) -> global___ContainerAwsNodePoolXConfigXConfigEncryption: ...
    @property
    def proxy_config(self) -> global___ContainerAwsNodePoolXConfigXProxyConfig: ...
    @property
    def root_volume(self) -> global___ContainerAwsNodePoolXConfigXRootVolume: ...
    @property
    def ssh_config(self) -> global___ContainerAwsNodePoolXConfigXSshConfig: ...
    @property
    def taints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerAwsNodePoolXConfigXTaints]: ...
    def __init__(
        self,
        *,
        iam_instance_profile: builtins.str = ...,
        instance_type: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config_encryption: global___ContainerAwsNodePoolXConfigXConfigEncryption | None = ...,
        proxy_config: global___ContainerAwsNodePoolXConfigXProxyConfig | None = ...,
        root_volume: global___ContainerAwsNodePoolXConfigXRootVolume | None = ...,
        ssh_config: global___ContainerAwsNodePoolXConfigXSshConfig | None = ...,
        taints: collections.abc.Iterable[global___ContainerAwsNodePoolXConfigXTaints] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config_encryption", b"config_encryption", "proxy_config", b"proxy_config", "root_volume", b"root_volume", "ssh_config", b"ssh_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_encryption", b"config_encryption", "iam_instance_profile", b"iam_instance_profile", "instance_type", b"instance_type", "labels", b"labels", "proxy_config", b"proxy_config", "root_volume", b"root_volume", "security_group_ids", b"security_group_ids", "ssh_config", b"ssh_config", "tags", b"tags", "taints", b"taints"]) -> None: ...

global___ContainerAwsNodePoolXConfig = ContainerAwsNodePoolXConfig

@typing_extensions.final
class ContainerAwsNodePoolXMaxPodsConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_PODS_PER_NODE_FIELD_NUMBER: builtins.int
    max_pods_per_node: builtins.float
    def __init__(
        self,
        *,
        max_pods_per_node: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_pods_per_node", b"max_pods_per_node"]) -> None: ...

global___ContainerAwsNodePoolXMaxPodsConstraint = ContainerAwsNodePoolXMaxPodsConstraint

@typing_extensions.final
class ContainerAwsNodePoolXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ContainerAwsNodePoolXTimeouts = ContainerAwsNodePoolXTimeouts

@typing_extensions.final
class ContainerAwsNodePool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANNOTATIONS_FIELD_NUMBER: builtins.int
    CLUSTER_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RECONCILING_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    AUTOSCALING_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    MAX_PODS_CONSTRAINT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    cluster: builtins.str
    create_time: builtins.str
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    reconciling: builtins.bool
    state: builtins.str
    subnet_id: builtins.str
    uid: builtins.str
    update_time: builtins.str
    version: builtins.str
    @property
    def autoscaling(self) -> global___ContainerAwsNodePoolXAutoscaling: ...
    @property
    def config(self) -> global___ContainerAwsNodePoolXConfig: ...
    @property
    def max_pods_constraint(self) -> global___ContainerAwsNodePoolXMaxPodsConstraint: ...
    @property
    def timeouts(self) -> global___ContainerAwsNodePoolXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        cluster: builtins.str = ...,
        create_time: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        reconciling: builtins.bool = ...,
        state: builtins.str = ...,
        subnet_id: builtins.str = ...,
        uid: builtins.str = ...,
        update_time: builtins.str = ...,
        version: builtins.str = ...,
        autoscaling: global___ContainerAwsNodePoolXAutoscaling | None = ...,
        config: global___ContainerAwsNodePoolXConfig | None = ...,
        max_pods_constraint: global___ContainerAwsNodePoolXMaxPodsConstraint | None = ...,
        timeouts: global___ContainerAwsNodePoolXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscaling", b"autoscaling", "config", b"config", "max_pods_constraint", b"max_pods_constraint", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "autoscaling", b"autoscaling", "cluster", b"cluster", "config", b"config", "create_time", b"create_time", "etag", b"etag", "id", b"id", "location", b"location", "max_pods_constraint", b"max_pods_constraint", "name", b"name", "project", b"project", "reconciling", b"reconciling", "resource_info", b"resource_info", "state", b"state", "subnet_id", b"subnet_id", "timeouts", b"timeouts", "uid", b"uid", "update_time", b"update_time", "version", b"version"]) -> None: ...

global___ContainerAwsNodePool = ContainerAwsNodePool

@typing_extensions.final
class ContainerAzureClientXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ContainerAzureClientXTimeouts = ContainerAzureClientXTimeouts

@typing_extensions.final
class ContainerAzureClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    certificate: builtins.str
    create_time: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    tenant_id: builtins.str
    uid: builtins.str
    @property
    def timeouts(self) -> global___ContainerAzureClientXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        certificate: builtins.str = ...,
        create_time: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        tenant_id: builtins.str = ...,
        uid: builtins.str = ...,
        timeouts: global___ContainerAzureClientXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_id", b"application_id", "certificate", b"certificate", "create_time", b"create_time", "id", b"id", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "tenant_id", b"tenant_id", "timeouts", b"timeouts", "uid", b"uid"]) -> None: ...

global___ContainerAzureClient = ContainerAzureClient

@typing_extensions.final
class ContainerAzureClusterXAuthorizationXAdminUsers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    username: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["username", b"username"]) -> None: ...

global___ContainerAzureClusterXAuthorizationXAdminUsers = ContainerAzureClusterXAuthorizationXAdminUsers

@typing_extensions.final
class ContainerAzureClusterXAuthorization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMIN_USERS_FIELD_NUMBER: builtins.int
    @property
    def admin_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerAzureClusterXAuthorizationXAdminUsers]: ...
    def __init__(
        self,
        *,
        admin_users: collections.abc.Iterable[global___ContainerAzureClusterXAuthorizationXAdminUsers] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_users", b"admin_users"]) -> None: ...

global___ContainerAzureClusterXAuthorization = ContainerAzureClusterXAuthorization

@typing_extensions.final
class ContainerAzureClusterXControlPlaneXDatabaseEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_id", b"key_id"]) -> None: ...

global___ContainerAzureClusterXControlPlaneXDatabaseEncryption = ContainerAzureClusterXControlPlaneXDatabaseEncryption

@typing_extensions.final
class ContainerAzureClusterXControlPlaneXMainVolume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_GIB_FIELD_NUMBER: builtins.int
    size_gib: builtins.float
    def __init__(
        self,
        *,
        size_gib: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["size_gib", b"size_gib"]) -> None: ...

global___ContainerAzureClusterXControlPlaneXMainVolume = ContainerAzureClusterXControlPlaneXMainVolume

@typing_extensions.final
class ContainerAzureClusterXControlPlaneXProxyConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_GROUP_ID_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    resource_group_id: builtins.str
    secret_id: builtins.str
    def __init__(
        self,
        *,
        resource_group_id: builtins.str = ...,
        secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_group_id", b"resource_group_id", "secret_id", b"secret_id"]) -> None: ...

global___ContainerAzureClusterXControlPlaneXProxyConfig = ContainerAzureClusterXControlPlaneXProxyConfig

@typing_extensions.final
class ContainerAzureClusterXControlPlaneXReplicaPlacements(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AZURE_AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    azure_availability_zone: builtins.str
    subnet_id: builtins.str
    def __init__(
        self,
        *,
        azure_availability_zone: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_availability_zone", b"azure_availability_zone", "subnet_id", b"subnet_id"]) -> None: ...

global___ContainerAzureClusterXControlPlaneXReplicaPlacements = ContainerAzureClusterXControlPlaneXReplicaPlacements

@typing_extensions.final
class ContainerAzureClusterXControlPlaneXRootVolume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_GIB_FIELD_NUMBER: builtins.int
    size_gib: builtins.float
    def __init__(
        self,
        *,
        size_gib: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["size_gib", b"size_gib"]) -> None: ...

global___ContainerAzureClusterXControlPlaneXRootVolume = ContainerAzureClusterXControlPlaneXRootVolume

@typing_extensions.final
class ContainerAzureClusterXControlPlaneXSshConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHORIZED_KEY_FIELD_NUMBER: builtins.int
    authorized_key: builtins.str
    def __init__(
        self,
        *,
        authorized_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorized_key", b"authorized_key"]) -> None: ...

global___ContainerAzureClusterXControlPlaneXSshConfig = ContainerAzureClusterXControlPlaneXSshConfig

@typing_extensions.final
class ContainerAzureClusterXControlPlane(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    SUBNET_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    VM_SIZE_FIELD_NUMBER: builtins.int
    DATABASE_ENCRYPTION_FIELD_NUMBER: builtins.int
    MAIN_VOLUME_FIELD_NUMBER: builtins.int
    PROXY_CONFIG_FIELD_NUMBER: builtins.int
    REPLICA_PLACEMENTS_FIELD_NUMBER: builtins.int
    ROOT_VOLUME_FIELD_NUMBER: builtins.int
    SSH_CONFIG_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    version: builtins.str
    vm_size: builtins.str
    @property
    def database_encryption(self) -> global___ContainerAzureClusterXControlPlaneXDatabaseEncryption: ...
    @property
    def main_volume(self) -> global___ContainerAzureClusterXControlPlaneXMainVolume: ...
    @property
    def proxy_config(self) -> global___ContainerAzureClusterXControlPlaneXProxyConfig: ...
    @property
    def replica_placements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerAzureClusterXControlPlaneXReplicaPlacements]: ...
    @property
    def root_volume(self) -> global___ContainerAzureClusterXControlPlaneXRootVolume: ...
    @property
    def ssh_config(self) -> global___ContainerAzureClusterXControlPlaneXSshConfig: ...
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        version: builtins.str = ...,
        vm_size: builtins.str = ...,
        database_encryption: global___ContainerAzureClusterXControlPlaneXDatabaseEncryption | None = ...,
        main_volume: global___ContainerAzureClusterXControlPlaneXMainVolume | None = ...,
        proxy_config: global___ContainerAzureClusterXControlPlaneXProxyConfig | None = ...,
        replica_placements: collections.abc.Iterable[global___ContainerAzureClusterXControlPlaneXReplicaPlacements] | None = ...,
        root_volume: global___ContainerAzureClusterXControlPlaneXRootVolume | None = ...,
        ssh_config: global___ContainerAzureClusterXControlPlaneXSshConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["database_encryption", b"database_encryption", "main_volume", b"main_volume", "proxy_config", b"proxy_config", "root_volume", b"root_volume", "ssh_config", b"ssh_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_encryption", b"database_encryption", "main_volume", b"main_volume", "proxy_config", b"proxy_config", "replica_placements", b"replica_placements", "root_volume", b"root_volume", "ssh_config", b"ssh_config", "subnet_id", b"subnet_id", "tags", b"tags", "version", b"version", "vm_size", b"vm_size"]) -> None: ...

global___ContainerAzureClusterXControlPlane = ContainerAzureClusterXControlPlane

@typing_extensions.final
class ContainerAzureClusterXFleet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMBERSHIP_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    membership: builtins.str
    project: builtins.str
    def __init__(
        self,
        *,
        membership: builtins.str = ...,
        project: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["membership", b"membership", "project", b"project"]) -> None: ...

global___ContainerAzureClusterXFleet = ContainerAzureClusterXFleet

@typing_extensions.final
class ContainerAzureClusterXNetworking(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POD_ADDRESS_CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    SERVICE_ADDRESS_CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_ID_FIELD_NUMBER: builtins.int
    @property
    def pod_address_cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def service_address_cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    virtual_network_id: builtins.str
    def __init__(
        self,
        *,
        pod_address_cidr_blocks: collections.abc.Iterable[builtins.str] | None = ...,
        service_address_cidr_blocks: collections.abc.Iterable[builtins.str] | None = ...,
        virtual_network_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pod_address_cidr_blocks", b"pod_address_cidr_blocks", "service_address_cidr_blocks", b"service_address_cidr_blocks", "virtual_network_id", b"virtual_network_id"]) -> None: ...

global___ContainerAzureClusterXNetworking = ContainerAzureClusterXNetworking

@typing_extensions.final
class ContainerAzureClusterXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ContainerAzureClusterXTimeouts = ContainerAzureClusterXTimeouts

@typing_extensions.final
class ContainerAzureCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class WorkloadIdentityConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANNOTATIONS_FIELD_NUMBER: builtins.int
    AZURE_REGION_FIELD_NUMBER: builtins.int
    CLIENT_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RECONCILING_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    WORKLOAD_IDENTITY_CONFIG_FIELD_NUMBER: builtins.int
    AUTHORIZATION_FIELD_NUMBER: builtins.int
    CONTROL_PLANE_FIELD_NUMBER: builtins.int
    FLEET_FIELD_NUMBER: builtins.int
    NETWORKING_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    azure_region: builtins.str
    client: builtins.str
    create_time: builtins.str
    description: builtins.str
    endpoint: builtins.str
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    reconciling: builtins.bool
    resource_group_id: builtins.str
    state: builtins.str
    uid: builtins.str
    update_time: builtins.str
    @property
    def workload_identity_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def authorization(self) -> global___ContainerAzureClusterXAuthorization: ...
    @property
    def control_plane(self) -> global___ContainerAzureClusterXControlPlane: ...
    @property
    def fleet(self) -> global___ContainerAzureClusterXFleet: ...
    @property
    def networking(self) -> global___ContainerAzureClusterXNetworking: ...
    @property
    def timeouts(self) -> global___ContainerAzureClusterXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        azure_region: builtins.str = ...,
        client: builtins.str = ...,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        endpoint: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        reconciling: builtins.bool = ...,
        resource_group_id: builtins.str = ...,
        state: builtins.str = ...,
        uid: builtins.str = ...,
        update_time: builtins.str = ...,
        workload_identity_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        authorization: global___ContainerAzureClusterXAuthorization | None = ...,
        control_plane: global___ContainerAzureClusterXControlPlane | None = ...,
        fleet: global___ContainerAzureClusterXFleet | None = ...,
        networking: global___ContainerAzureClusterXNetworking | None = ...,
        timeouts: global___ContainerAzureClusterXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authorization", b"authorization", "control_plane", b"control_plane", "fleet", b"fleet", "networking", b"networking", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "authorization", b"authorization", "azure_region", b"azure_region", "client", b"client", "control_plane", b"control_plane", "create_time", b"create_time", "description", b"description", "endpoint", b"endpoint", "etag", b"etag", "fleet", b"fleet", "id", b"id", "location", b"location", "name", b"name", "networking", b"networking", "project", b"project", "reconciling", b"reconciling", "resource_group_id", b"resource_group_id", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts", "uid", b"uid", "update_time", b"update_time", "workload_identity_config", b"workload_identity_config"]) -> None: ...

global___ContainerAzureCluster = ContainerAzureCluster

@typing_extensions.final
class ContainerAzureNodePoolXAutoscaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_NODE_COUNT_FIELD_NUMBER: builtins.int
    MIN_NODE_COUNT_FIELD_NUMBER: builtins.int
    max_node_count: builtins.float
    min_node_count: builtins.float
    def __init__(
        self,
        *,
        max_node_count: builtins.float = ...,
        min_node_count: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_node_count", b"max_node_count", "min_node_count", b"min_node_count"]) -> None: ...

global___ContainerAzureNodePoolXAutoscaling = ContainerAzureNodePoolXAutoscaling

@typing_extensions.final
class ContainerAzureNodePoolXConfigXProxyConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_GROUP_ID_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    resource_group_id: builtins.str
    secret_id: builtins.str
    def __init__(
        self,
        *,
        resource_group_id: builtins.str = ...,
        secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_group_id", b"resource_group_id", "secret_id", b"secret_id"]) -> None: ...

global___ContainerAzureNodePoolXConfigXProxyConfig = ContainerAzureNodePoolXConfigXProxyConfig

@typing_extensions.final
class ContainerAzureNodePoolXConfigXRootVolume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_GIB_FIELD_NUMBER: builtins.int
    size_gib: builtins.float
    def __init__(
        self,
        *,
        size_gib: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["size_gib", b"size_gib"]) -> None: ...

global___ContainerAzureNodePoolXConfigXRootVolume = ContainerAzureNodePoolXConfigXRootVolume

@typing_extensions.final
class ContainerAzureNodePoolXConfigXSshConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHORIZED_KEY_FIELD_NUMBER: builtins.int
    authorized_key: builtins.str
    def __init__(
        self,
        *,
        authorized_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorized_key", b"authorized_key"]) -> None: ...

global___ContainerAzureNodePoolXConfigXSshConfig = ContainerAzureNodePoolXConfigXSshConfig

@typing_extensions.final
class ContainerAzureNodePoolXConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TAGS_FIELD_NUMBER: builtins.int
    VM_SIZE_FIELD_NUMBER: builtins.int
    PROXY_CONFIG_FIELD_NUMBER: builtins.int
    ROOT_VOLUME_FIELD_NUMBER: builtins.int
    SSH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    vm_size: builtins.str
    @property
    def proxy_config(self) -> global___ContainerAzureNodePoolXConfigXProxyConfig: ...
    @property
    def root_volume(self) -> global___ContainerAzureNodePoolXConfigXRootVolume: ...
    @property
    def ssh_config(self) -> global___ContainerAzureNodePoolXConfigXSshConfig: ...
    def __init__(
        self,
        *,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vm_size: builtins.str = ...,
        proxy_config: global___ContainerAzureNodePoolXConfigXProxyConfig | None = ...,
        root_volume: global___ContainerAzureNodePoolXConfigXRootVolume | None = ...,
        ssh_config: global___ContainerAzureNodePoolXConfigXSshConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["proxy_config", b"proxy_config", "root_volume", b"root_volume", "ssh_config", b"ssh_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["proxy_config", b"proxy_config", "root_volume", b"root_volume", "ssh_config", b"ssh_config", "tags", b"tags", "vm_size", b"vm_size"]) -> None: ...

global___ContainerAzureNodePoolXConfig = ContainerAzureNodePoolXConfig

@typing_extensions.final
class ContainerAzureNodePoolXMaxPodsConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_PODS_PER_NODE_FIELD_NUMBER: builtins.int
    max_pods_per_node: builtins.float
    def __init__(
        self,
        *,
        max_pods_per_node: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_pods_per_node", b"max_pods_per_node"]) -> None: ...

global___ContainerAzureNodePoolXMaxPodsConstraint = ContainerAzureNodePoolXMaxPodsConstraint

@typing_extensions.final
class ContainerAzureNodePoolXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ContainerAzureNodePoolXTimeouts = ContainerAzureNodePoolXTimeouts

@typing_extensions.final
class ContainerAzureNodePool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANNOTATIONS_FIELD_NUMBER: builtins.int
    AZURE_AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    CLUSTER_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RECONCILING_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    AUTOSCALING_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    MAX_PODS_CONSTRAINT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    azure_availability_zone: builtins.str
    cluster: builtins.str
    create_time: builtins.str
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    reconciling: builtins.bool
    state: builtins.str
    subnet_id: builtins.str
    uid: builtins.str
    update_time: builtins.str
    version: builtins.str
    @property
    def autoscaling(self) -> global___ContainerAzureNodePoolXAutoscaling: ...
    @property
    def config(self) -> global___ContainerAzureNodePoolXConfig: ...
    @property
    def max_pods_constraint(self) -> global___ContainerAzureNodePoolXMaxPodsConstraint: ...
    @property
    def timeouts(self) -> global___ContainerAzureNodePoolXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        azure_availability_zone: builtins.str = ...,
        cluster: builtins.str = ...,
        create_time: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        reconciling: builtins.bool = ...,
        state: builtins.str = ...,
        subnet_id: builtins.str = ...,
        uid: builtins.str = ...,
        update_time: builtins.str = ...,
        version: builtins.str = ...,
        autoscaling: global___ContainerAzureNodePoolXAutoscaling | None = ...,
        config: global___ContainerAzureNodePoolXConfig | None = ...,
        max_pods_constraint: global___ContainerAzureNodePoolXMaxPodsConstraint | None = ...,
        timeouts: global___ContainerAzureNodePoolXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscaling", b"autoscaling", "config", b"config", "max_pods_constraint", b"max_pods_constraint", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "autoscaling", b"autoscaling", "azure_availability_zone", b"azure_availability_zone", "cluster", b"cluster", "config", b"config", "create_time", b"create_time", "etag", b"etag", "id", b"id", "location", b"location", "max_pods_constraint", b"max_pods_constraint", "name", b"name", "project", b"project", "reconciling", b"reconciling", "resource_info", b"resource_info", "state", b"state", "subnet_id", b"subnet_id", "timeouts", b"timeouts", "uid", b"uid", "update_time", b"update_time", "version", b"version"]) -> None: ...

global___ContainerAzureNodePool = ContainerAzureNodePool

@typing_extensions.final
class ContainerClusterXAddonsConfigXCloudrunConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_TYPE_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    load_balancer_type: builtins.str
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
        load_balancer_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled", b"disabled", "load_balancer_type", b"load_balancer_type"]) -> None: ...

global___ContainerClusterXAddonsConfigXCloudrunConfig = ContainerClusterXAddonsConfigXCloudrunConfig

@typing_extensions.final
class ContainerClusterXAddonsConfigXDnsCacheConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ContainerClusterXAddonsConfigXDnsCacheConfig = ContainerClusterXAddonsConfigXDnsCacheConfig

@typing_extensions.final
class ContainerClusterXAddonsConfigXGcePersistentDiskCsiDriverConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ContainerClusterXAddonsConfigXGcePersistentDiskCsiDriverConfig = ContainerClusterXAddonsConfigXGcePersistentDiskCsiDriverConfig

@typing_extensions.final
class ContainerClusterXAddonsConfigXGcpFilestoreCsiDriverConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ContainerClusterXAddonsConfigXGcpFilestoreCsiDriverConfig = ContainerClusterXAddonsConfigXGcpFilestoreCsiDriverConfig

@typing_extensions.final
class ContainerClusterXAddonsConfigXHorizontalPodAutoscaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled", b"disabled"]) -> None: ...

global___ContainerClusterXAddonsConfigXHorizontalPodAutoscaling = ContainerClusterXAddonsConfigXHorizontalPodAutoscaling

@typing_extensions.final
class ContainerClusterXAddonsConfigXHttpLoadBalancing(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled", b"disabled"]) -> None: ...

global___ContainerClusterXAddonsConfigXHttpLoadBalancing = ContainerClusterXAddonsConfigXHttpLoadBalancing

@typing_extensions.final
class ContainerClusterXAddonsConfigXNetworkPolicyConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled", b"disabled"]) -> None: ...

global___ContainerClusterXAddonsConfigXNetworkPolicyConfig = ContainerClusterXAddonsConfigXNetworkPolicyConfig

@typing_extensions.final
class ContainerClusterXAddonsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUDRUN_CONFIG_FIELD_NUMBER: builtins.int
    DNS_CACHE_CONFIG_FIELD_NUMBER: builtins.int
    GCE_PERSISTENT_DISK_CSI_DRIVER_CONFIG_FIELD_NUMBER: builtins.int
    GCP_FILESTORE_CSI_DRIVER_CONFIG_FIELD_NUMBER: builtins.int
    HORIZONTAL_POD_AUTOSCALING_FIELD_NUMBER: builtins.int
    HTTP_LOAD_BALANCING_FIELD_NUMBER: builtins.int
    NETWORK_POLICY_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def cloudrun_config(self) -> global___ContainerClusterXAddonsConfigXCloudrunConfig: ...
    @property
    def dns_cache_config(self) -> global___ContainerClusterXAddonsConfigXDnsCacheConfig: ...
    @property
    def gce_persistent_disk_csi_driver_config(self) -> global___ContainerClusterXAddonsConfigXGcePersistentDiskCsiDriverConfig: ...
    @property
    def gcp_filestore_csi_driver_config(self) -> global___ContainerClusterXAddonsConfigXGcpFilestoreCsiDriverConfig: ...
    @property
    def horizontal_pod_autoscaling(self) -> global___ContainerClusterXAddonsConfigXHorizontalPodAutoscaling: ...
    @property
    def http_load_balancing(self) -> global___ContainerClusterXAddonsConfigXHttpLoadBalancing: ...
    @property
    def network_policy_config(self) -> global___ContainerClusterXAddonsConfigXNetworkPolicyConfig: ...
    def __init__(
        self,
        *,
        cloudrun_config: global___ContainerClusterXAddonsConfigXCloudrunConfig | None = ...,
        dns_cache_config: global___ContainerClusterXAddonsConfigXDnsCacheConfig | None = ...,
        gce_persistent_disk_csi_driver_config: global___ContainerClusterXAddonsConfigXGcePersistentDiskCsiDriverConfig | None = ...,
        gcp_filestore_csi_driver_config: global___ContainerClusterXAddonsConfigXGcpFilestoreCsiDriverConfig | None = ...,
        horizontal_pod_autoscaling: global___ContainerClusterXAddonsConfigXHorizontalPodAutoscaling | None = ...,
        http_load_balancing: global___ContainerClusterXAddonsConfigXHttpLoadBalancing | None = ...,
        network_policy_config: global___ContainerClusterXAddonsConfigXNetworkPolicyConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloudrun_config", b"cloudrun_config", "dns_cache_config", b"dns_cache_config", "gce_persistent_disk_csi_driver_config", b"gce_persistent_disk_csi_driver_config", "gcp_filestore_csi_driver_config", b"gcp_filestore_csi_driver_config", "horizontal_pod_autoscaling", b"horizontal_pod_autoscaling", "http_load_balancing", b"http_load_balancing", "network_policy_config", b"network_policy_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloudrun_config", b"cloudrun_config", "dns_cache_config", b"dns_cache_config", "gce_persistent_disk_csi_driver_config", b"gce_persistent_disk_csi_driver_config", "gcp_filestore_csi_driver_config", b"gcp_filestore_csi_driver_config", "horizontal_pod_autoscaling", b"horizontal_pod_autoscaling", "http_load_balancing", b"http_load_balancing", "network_policy_config", b"network_policy_config"]) -> None: ...

global___ContainerClusterXAddonsConfig = ContainerClusterXAddonsConfig

@typing_extensions.final
class ContainerClusterXAuthenticatorGroupsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_FIELD_NUMBER: builtins.int
    security_group: builtins.str
    def __init__(
        self,
        *,
        security_group: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["security_group", b"security_group"]) -> None: ...

global___ContainerClusterXAuthenticatorGroupsConfig = ContainerClusterXAuthenticatorGroupsConfig

@typing_extensions.final
class ContainerClusterXBinaryAuthorization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    EVALUATION_MODE_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    evaluation_mode: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        evaluation_mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "evaluation_mode", b"evaluation_mode"]) -> None: ...

global___ContainerClusterXBinaryAuthorization = ContainerClusterXBinaryAuthorization

@typing_extensions.final
class ContainerClusterXClusterAutoscalingXAutoProvisioningDefaults(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOT_DISK_KMS_KEY_FIELD_NUMBER: builtins.int
    IMAGE_TYPE_FIELD_NUMBER: builtins.int
    OAUTH_SCOPES_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    boot_disk_kms_key: builtins.str
    image_type: builtins.str
    @property
    def oauth_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    service_account: builtins.str
    def __init__(
        self,
        *,
        boot_disk_kms_key: builtins.str = ...,
        image_type: builtins.str = ...,
        oauth_scopes: collections.abc.Iterable[builtins.str] | None = ...,
        service_account: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["boot_disk_kms_key", b"boot_disk_kms_key", "image_type", b"image_type", "oauth_scopes", b"oauth_scopes", "service_account", b"service_account"]) -> None: ...

global___ContainerClusterXClusterAutoscalingXAutoProvisioningDefaults = ContainerClusterXClusterAutoscalingXAutoProvisioningDefaults

@typing_extensions.final
class ContainerClusterXClusterAutoscalingXResourceLimits(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAXIMUM_FIELD_NUMBER: builtins.int
    MINIMUM_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    maximum: builtins.float
    minimum: builtins.float
    resource_type: builtins.str
    def __init__(
        self,
        *,
        maximum: builtins.float = ...,
        minimum: builtins.float = ...,
        resource_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["maximum", b"maximum", "minimum", b"minimum", "resource_type", b"resource_type"]) -> None: ...

global___ContainerClusterXClusterAutoscalingXResourceLimits = ContainerClusterXClusterAutoscalingXResourceLimits

@typing_extensions.final
class ContainerClusterXClusterAutoscaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    AUTO_PROVISIONING_DEFAULTS_FIELD_NUMBER: builtins.int
    RESOURCE_LIMITS_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    @property
    def auto_provisioning_defaults(self) -> global___ContainerClusterXClusterAutoscalingXAutoProvisioningDefaults: ...
    @property
    def resource_limits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerClusterXClusterAutoscalingXResourceLimits]: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        auto_provisioning_defaults: global___ContainerClusterXClusterAutoscalingXAutoProvisioningDefaults | None = ...,
        resource_limits: collections.abc.Iterable[global___ContainerClusterXClusterAutoscalingXResourceLimits] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_provisioning_defaults", b"auto_provisioning_defaults"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_provisioning_defaults", b"auto_provisioning_defaults", "enabled", b"enabled", "resource_limits", b"resource_limits"]) -> None: ...

global___ContainerClusterXClusterAutoscaling = ContainerClusterXClusterAutoscaling

@typing_extensions.final
class ContainerClusterXConfidentialNodes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ContainerClusterXConfidentialNodes = ContainerClusterXConfidentialNodes

@typing_extensions.final
class ContainerClusterXDatabaseEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_NAME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    key_name: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        key_name: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_name", b"key_name", "state", b"state"]) -> None: ...

global___ContainerClusterXDatabaseEncryption = ContainerClusterXDatabaseEncryption

@typing_extensions.final
class ContainerClusterXDefaultSnatStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled", b"disabled"]) -> None: ...

global___ContainerClusterXDefaultSnatStatus = ContainerClusterXDefaultSnatStatus

@typing_extensions.final
class ContainerClusterXDnsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_DNS_FIELD_NUMBER: builtins.int
    CLUSTER_DNS_DOMAIN_FIELD_NUMBER: builtins.int
    CLUSTER_DNS_SCOPE_FIELD_NUMBER: builtins.int
    cluster_dns: builtins.str
    cluster_dns_domain: builtins.str
    cluster_dns_scope: builtins.str
    def __init__(
        self,
        *,
        cluster_dns: builtins.str = ...,
        cluster_dns_domain: builtins.str = ...,
        cluster_dns_scope: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_dns", b"cluster_dns", "cluster_dns_domain", b"cluster_dns_domain", "cluster_dns_scope", b"cluster_dns_scope"]) -> None: ...

global___ContainerClusterXDnsConfig = ContainerClusterXDnsConfig

@typing_extensions.final
class ContainerClusterXIpAllocationPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_IPV4_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    CLUSTER_SECONDARY_RANGE_NAME_FIELD_NUMBER: builtins.int
    SERVICES_IPV4_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    SERVICES_SECONDARY_RANGE_NAME_FIELD_NUMBER: builtins.int
    cluster_ipv4_cidr_block: builtins.str
    cluster_secondary_range_name: builtins.str
    services_ipv4_cidr_block: builtins.str
    services_secondary_range_name: builtins.str
    def __init__(
        self,
        *,
        cluster_ipv4_cidr_block: builtins.str = ...,
        cluster_secondary_range_name: builtins.str = ...,
        services_ipv4_cidr_block: builtins.str = ...,
        services_secondary_range_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_ipv4_cidr_block", b"cluster_ipv4_cidr_block", "cluster_secondary_range_name", b"cluster_secondary_range_name", "services_ipv4_cidr_block", b"services_ipv4_cidr_block", "services_secondary_range_name", b"services_secondary_range_name"]) -> None: ...

global___ContainerClusterXIpAllocationPolicy = ContainerClusterXIpAllocationPolicy

@typing_extensions.final
class ContainerClusterXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_COMPONENTS_FIELD_NUMBER: builtins.int
    @property
    def enable_components(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        enable_components: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_components", b"enable_components"]) -> None: ...

global___ContainerClusterXLoggingConfig = ContainerClusterXLoggingConfig

@typing_extensions.final
class ContainerClusterXMaintenancePolicyXDailyMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DURATION_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    duration: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        duration: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "start_time", b"start_time"]) -> None: ...

global___ContainerClusterXMaintenancePolicyXDailyMaintenanceWindow = ContainerClusterXMaintenancePolicyXDailyMaintenanceWindow

@typing_extensions.final
class ContainerClusterXMaintenancePolicyXMaintenanceExclusionXExclusionOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCOPE_FIELD_NUMBER: builtins.int
    scope: builtins.str
    def __init__(
        self,
        *,
        scope: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scope", b"scope"]) -> None: ...

global___ContainerClusterXMaintenancePolicyXMaintenanceExclusionXExclusionOptions = ContainerClusterXMaintenancePolicyXMaintenanceExclusionXExclusionOptions

@typing_extensions.final
class ContainerClusterXMaintenancePolicyXMaintenanceExclusion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    END_TIME_FIELD_NUMBER: builtins.int
    EXCLUSION_NAME_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    EXCLUSION_OPTIONS_FIELD_NUMBER: builtins.int
    end_time: builtins.str
    exclusion_name: builtins.str
    start_time: builtins.str
    @property
    def exclusion_options(self) -> global___ContainerClusterXMaintenancePolicyXMaintenanceExclusionXExclusionOptions: ...
    def __init__(
        self,
        *,
        end_time: builtins.str = ...,
        exclusion_name: builtins.str = ...,
        start_time: builtins.str = ...,
        exclusion_options: global___ContainerClusterXMaintenancePolicyXMaintenanceExclusionXExclusionOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exclusion_options", b"exclusion_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "exclusion_name", b"exclusion_name", "exclusion_options", b"exclusion_options", "start_time", b"start_time"]) -> None: ...

global___ContainerClusterXMaintenancePolicyXMaintenanceExclusion = ContainerClusterXMaintenancePolicyXMaintenanceExclusion

@typing_extensions.final
class ContainerClusterXMaintenancePolicyXRecurringWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    END_TIME_FIELD_NUMBER: builtins.int
    RECURRENCE_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    end_time: builtins.str
    recurrence: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        end_time: builtins.str = ...,
        recurrence: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "recurrence", b"recurrence", "start_time", b"start_time"]) -> None: ...

global___ContainerClusterXMaintenancePolicyXRecurringWindow = ContainerClusterXMaintenancePolicyXRecurringWindow

@typing_extensions.final
class ContainerClusterXMaintenancePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAILY_MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    MAINTENANCE_EXCLUSION_FIELD_NUMBER: builtins.int
    RECURRING_WINDOW_FIELD_NUMBER: builtins.int
    @property
    def daily_maintenance_window(self) -> global___ContainerClusterXMaintenancePolicyXDailyMaintenanceWindow: ...
    @property
    def maintenance_exclusion(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerClusterXMaintenancePolicyXMaintenanceExclusion]: ...
    @property
    def recurring_window(self) -> global___ContainerClusterXMaintenancePolicyXRecurringWindow: ...
    def __init__(
        self,
        *,
        daily_maintenance_window: global___ContainerClusterXMaintenancePolicyXDailyMaintenanceWindow | None = ...,
        maintenance_exclusion: collections.abc.Iterable[global___ContainerClusterXMaintenancePolicyXMaintenanceExclusion] | None = ...,
        recurring_window: global___ContainerClusterXMaintenancePolicyXRecurringWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["daily_maintenance_window", b"daily_maintenance_window", "recurring_window", b"recurring_window"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["daily_maintenance_window", b"daily_maintenance_window", "maintenance_exclusion", b"maintenance_exclusion", "recurring_window", b"recurring_window"]) -> None: ...

global___ContainerClusterXMaintenancePolicy = ContainerClusterXMaintenancePolicy

@typing_extensions.final
class ContainerClusterXMasterAuthXClientCertificateConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISSUE_CLIENT_CERTIFICATE_FIELD_NUMBER: builtins.int
    issue_client_certificate: builtins.bool
    def __init__(
        self,
        *,
        issue_client_certificate: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["issue_client_certificate", b"issue_client_certificate"]) -> None: ...

global___ContainerClusterXMasterAuthXClientCertificateConfig = ContainerClusterXMasterAuthXClientCertificateConfig

@typing_extensions.final
class ContainerClusterXMasterAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_CERTIFICATE_FIELD_NUMBER: builtins.int
    CLIENT_KEY_FIELD_NUMBER: builtins.int
    CLUSTER_CA_CERTIFICATE_FIELD_NUMBER: builtins.int
    CLIENT_CERTIFICATE_CONFIG_FIELD_NUMBER: builtins.int
    client_certificate: builtins.str
    client_key: builtins.str
    cluster_ca_certificate: builtins.str
    @property
    def client_certificate_config(self) -> global___ContainerClusterXMasterAuthXClientCertificateConfig: ...
    def __init__(
        self,
        *,
        client_certificate: builtins.str = ...,
        client_key: builtins.str = ...,
        cluster_ca_certificate: builtins.str = ...,
        client_certificate_config: global___ContainerClusterXMasterAuthXClientCertificateConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_certificate_config", b"client_certificate_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_certificate", b"client_certificate", "client_certificate_config", b"client_certificate_config", "client_key", b"client_key", "cluster_ca_certificate", b"cluster_ca_certificate"]) -> None: ...

global___ContainerClusterXMasterAuth = ContainerClusterXMasterAuth

@typing_extensions.final
class ContainerClusterXMasterAuthorizedNetworksConfigXCidrBlocks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CIDR_BLOCK_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    cidr_block: builtins.str
    display_name: builtins.str
    def __init__(
        self,
        *,
        cidr_block: builtins.str = ...,
        display_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cidr_block", b"cidr_block", "display_name", b"display_name"]) -> None: ...

global___ContainerClusterXMasterAuthorizedNetworksConfigXCidrBlocks = ContainerClusterXMasterAuthorizedNetworksConfigXCidrBlocks

@typing_extensions.final
class ContainerClusterXMasterAuthorizedNetworksConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    @property
    def cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerClusterXMasterAuthorizedNetworksConfigXCidrBlocks]: ...
    def __init__(
        self,
        *,
        cidr_blocks: collections.abc.Iterable[global___ContainerClusterXMasterAuthorizedNetworksConfigXCidrBlocks] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cidr_blocks", b"cidr_blocks"]) -> None: ...

global___ContainerClusterXMasterAuthorizedNetworksConfig = ContainerClusterXMasterAuthorizedNetworksConfig

@typing_extensions.final
class ContainerClusterXMonitoringConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_COMPONENTS_FIELD_NUMBER: builtins.int
    @property
    def enable_components(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        enable_components: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_components", b"enable_components"]) -> None: ...

global___ContainerClusterXMonitoringConfig = ContainerClusterXMonitoringConfig

@typing_extensions.final
class ContainerClusterXNetworkPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    provider: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        provider: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "provider", b"provider"]) -> None: ...

global___ContainerClusterXNetworkPolicy = ContainerClusterXNetworkPolicy

@typing_extensions.final
class ContainerClusterXNodeConfigXGcfsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ContainerClusterXNodeConfigXGcfsConfig = ContainerClusterXNodeConfigXGcfsConfig

@typing_extensions.final
class ContainerClusterXNodeConfigXGvnic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ContainerClusterXNodeConfigXGvnic = ContainerClusterXNodeConfigXGvnic

@typing_extensions.final
class ContainerClusterXNodeConfigXShieldedInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_INTEGRITY_MONITORING_FIELD_NUMBER: builtins.int
    ENABLE_SECURE_BOOT_FIELD_NUMBER: builtins.int
    enable_integrity_monitoring: builtins.bool
    enable_secure_boot: builtins.bool
    def __init__(
        self,
        *,
        enable_integrity_monitoring: builtins.bool = ...,
        enable_secure_boot: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_integrity_monitoring", b"enable_integrity_monitoring", "enable_secure_boot", b"enable_secure_boot"]) -> None: ...

global___ContainerClusterXNodeConfigXShieldedInstanceConfig = ContainerClusterXNodeConfigXShieldedInstanceConfig

@typing_extensions.final
class ContainerClusterXNodeConfigXWorkloadMetadataConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODE_FIELD_NUMBER: builtins.int
    mode: builtins.str
    def __init__(
        self,
        *,
        mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mode", b"mode"]) -> None: ...

global___ContainerClusterXNodeConfigXWorkloadMetadataConfig = ContainerClusterXNodeConfigXWorkloadMetadataConfig

@typing_extensions.final
class ContainerClusterXNodeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class GuestAcceleratorEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TaintEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BOOT_DISK_KMS_KEY_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    DISK_TYPE_FIELD_NUMBER: builtins.int
    GUEST_ACCELERATOR_FIELD_NUMBER: builtins.int
    IMAGE_TYPE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCAL_SSD_COUNT_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    NODE_GROUP_FIELD_NUMBER: builtins.int
    OAUTH_SCOPES_FIELD_NUMBER: builtins.int
    PREEMPTIBLE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SPOT_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TAINT_FIELD_NUMBER: builtins.int
    GCFS_CONFIG_FIELD_NUMBER: builtins.int
    GVNIC_FIELD_NUMBER: builtins.int
    SHIELDED_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    WORKLOAD_METADATA_CONFIG_FIELD_NUMBER: builtins.int
    boot_disk_kms_key: builtins.str
    disk_size_gb: builtins.float
    disk_type: builtins.str
    @property
    def guest_accelerator(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    image_type: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    local_ssd_count: builtins.float
    machine_type: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    min_cpu_platform: builtins.str
    node_group: builtins.str
    @property
    def oauth_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    preemptible: builtins.bool
    service_account: builtins.str
    spot: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def taint(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def gcfs_config(self) -> global___ContainerClusterXNodeConfigXGcfsConfig: ...
    @property
    def gvnic(self) -> global___ContainerClusterXNodeConfigXGvnic: ...
    @property
    def shielded_instance_config(self) -> global___ContainerClusterXNodeConfigXShieldedInstanceConfig: ...
    @property
    def workload_metadata_config(self) -> global___ContainerClusterXNodeConfigXWorkloadMetadataConfig: ...
    def __init__(
        self,
        *,
        boot_disk_kms_key: builtins.str = ...,
        disk_size_gb: builtins.float = ...,
        disk_type: builtins.str = ...,
        guest_accelerator: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        image_type: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        local_ssd_count: builtins.float = ...,
        machine_type: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        min_cpu_platform: builtins.str = ...,
        node_group: builtins.str = ...,
        oauth_scopes: collections.abc.Iterable[builtins.str] | None = ...,
        preemptible: builtins.bool = ...,
        service_account: builtins.str = ...,
        spot: builtins.bool = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        taint: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        gcfs_config: global___ContainerClusterXNodeConfigXGcfsConfig | None = ...,
        gvnic: global___ContainerClusterXNodeConfigXGvnic | None = ...,
        shielded_instance_config: global___ContainerClusterXNodeConfigXShieldedInstanceConfig | None = ...,
        workload_metadata_config: global___ContainerClusterXNodeConfigXWorkloadMetadataConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcfs_config", b"gcfs_config", "gvnic", b"gvnic", "shielded_instance_config", b"shielded_instance_config", "workload_metadata_config", b"workload_metadata_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["boot_disk_kms_key", b"boot_disk_kms_key", "disk_size_gb", b"disk_size_gb", "disk_type", b"disk_type", "gcfs_config", b"gcfs_config", "guest_accelerator", b"guest_accelerator", "gvnic", b"gvnic", "image_type", b"image_type", "labels", b"labels", "local_ssd_count", b"local_ssd_count", "machine_type", b"machine_type", "metadata", b"metadata", "min_cpu_platform", b"min_cpu_platform", "node_group", b"node_group", "oauth_scopes", b"oauth_scopes", "preemptible", b"preemptible", "service_account", b"service_account", "shielded_instance_config", b"shielded_instance_config", "spot", b"spot", "tags", b"tags", "taint", b"taint", "workload_metadata_config", b"workload_metadata_config"]) -> None: ...

global___ContainerClusterXNodeConfig = ContainerClusterXNodeConfig

@typing_extensions.final
class ContainerClusterXNodePoolXAutoscaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_NODE_COUNT_FIELD_NUMBER: builtins.int
    MIN_NODE_COUNT_FIELD_NUMBER: builtins.int
    max_node_count: builtins.float
    min_node_count: builtins.float
    def __init__(
        self,
        *,
        max_node_count: builtins.float = ...,
        min_node_count: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_node_count", b"max_node_count", "min_node_count", b"min_node_count"]) -> None: ...

global___ContainerClusterXNodePoolXAutoscaling = ContainerClusterXNodePoolXAutoscaling

@typing_extensions.final
class ContainerClusterXNodePoolXManagement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_REPAIR_FIELD_NUMBER: builtins.int
    AUTO_UPGRADE_FIELD_NUMBER: builtins.int
    auto_repair: builtins.bool
    auto_upgrade: builtins.bool
    def __init__(
        self,
        *,
        auto_repair: builtins.bool = ...,
        auto_upgrade: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_repair", b"auto_repair", "auto_upgrade", b"auto_upgrade"]) -> None: ...

global___ContainerClusterXNodePoolXManagement = ContainerClusterXNodePoolXManagement

@typing_extensions.final
class ContainerClusterXNodePoolXNodeConfigXGcfsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ContainerClusterXNodePoolXNodeConfigXGcfsConfig = ContainerClusterXNodePoolXNodeConfigXGcfsConfig

@typing_extensions.final
class ContainerClusterXNodePoolXNodeConfigXGvnic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ContainerClusterXNodePoolXNodeConfigXGvnic = ContainerClusterXNodePoolXNodeConfigXGvnic

@typing_extensions.final
class ContainerClusterXNodePoolXNodeConfigXShieldedInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_INTEGRITY_MONITORING_FIELD_NUMBER: builtins.int
    ENABLE_SECURE_BOOT_FIELD_NUMBER: builtins.int
    enable_integrity_monitoring: builtins.bool
    enable_secure_boot: builtins.bool
    def __init__(
        self,
        *,
        enable_integrity_monitoring: builtins.bool = ...,
        enable_secure_boot: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_integrity_monitoring", b"enable_integrity_monitoring", "enable_secure_boot", b"enable_secure_boot"]) -> None: ...

global___ContainerClusterXNodePoolXNodeConfigXShieldedInstanceConfig = ContainerClusterXNodePoolXNodeConfigXShieldedInstanceConfig

@typing_extensions.final
class ContainerClusterXNodePoolXNodeConfigXWorkloadMetadataConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODE_FIELD_NUMBER: builtins.int
    mode: builtins.str
    def __init__(
        self,
        *,
        mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mode", b"mode"]) -> None: ...

global___ContainerClusterXNodePoolXNodeConfigXWorkloadMetadataConfig = ContainerClusterXNodePoolXNodeConfigXWorkloadMetadataConfig

@typing_extensions.final
class ContainerClusterXNodePoolXNodeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class GuestAcceleratorEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TaintEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BOOT_DISK_KMS_KEY_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    DISK_TYPE_FIELD_NUMBER: builtins.int
    GUEST_ACCELERATOR_FIELD_NUMBER: builtins.int
    IMAGE_TYPE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCAL_SSD_COUNT_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    NODE_GROUP_FIELD_NUMBER: builtins.int
    OAUTH_SCOPES_FIELD_NUMBER: builtins.int
    PREEMPTIBLE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SPOT_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TAINT_FIELD_NUMBER: builtins.int
    GCFS_CONFIG_FIELD_NUMBER: builtins.int
    GVNIC_FIELD_NUMBER: builtins.int
    SHIELDED_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    WORKLOAD_METADATA_CONFIG_FIELD_NUMBER: builtins.int
    boot_disk_kms_key: builtins.str
    disk_size_gb: builtins.float
    disk_type: builtins.str
    @property
    def guest_accelerator(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    image_type: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    local_ssd_count: builtins.float
    machine_type: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    min_cpu_platform: builtins.str
    node_group: builtins.str
    @property
    def oauth_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    preemptible: builtins.bool
    service_account: builtins.str
    spot: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def taint(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def gcfs_config(self) -> global___ContainerClusterXNodePoolXNodeConfigXGcfsConfig: ...
    @property
    def gvnic(self) -> global___ContainerClusterXNodePoolXNodeConfigXGvnic: ...
    @property
    def shielded_instance_config(self) -> global___ContainerClusterXNodePoolXNodeConfigXShieldedInstanceConfig: ...
    @property
    def workload_metadata_config(self) -> global___ContainerClusterXNodePoolXNodeConfigXWorkloadMetadataConfig: ...
    def __init__(
        self,
        *,
        boot_disk_kms_key: builtins.str = ...,
        disk_size_gb: builtins.float = ...,
        disk_type: builtins.str = ...,
        guest_accelerator: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        image_type: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        local_ssd_count: builtins.float = ...,
        machine_type: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        min_cpu_platform: builtins.str = ...,
        node_group: builtins.str = ...,
        oauth_scopes: collections.abc.Iterable[builtins.str] | None = ...,
        preemptible: builtins.bool = ...,
        service_account: builtins.str = ...,
        spot: builtins.bool = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        taint: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        gcfs_config: global___ContainerClusterXNodePoolXNodeConfigXGcfsConfig | None = ...,
        gvnic: global___ContainerClusterXNodePoolXNodeConfigXGvnic | None = ...,
        shielded_instance_config: global___ContainerClusterXNodePoolXNodeConfigXShieldedInstanceConfig | None = ...,
        workload_metadata_config: global___ContainerClusterXNodePoolXNodeConfigXWorkloadMetadataConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcfs_config", b"gcfs_config", "gvnic", b"gvnic", "shielded_instance_config", b"shielded_instance_config", "workload_metadata_config", b"workload_metadata_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["boot_disk_kms_key", b"boot_disk_kms_key", "disk_size_gb", b"disk_size_gb", "disk_type", b"disk_type", "gcfs_config", b"gcfs_config", "guest_accelerator", b"guest_accelerator", "gvnic", b"gvnic", "image_type", b"image_type", "labels", b"labels", "local_ssd_count", b"local_ssd_count", "machine_type", b"machine_type", "metadata", b"metadata", "min_cpu_platform", b"min_cpu_platform", "node_group", b"node_group", "oauth_scopes", b"oauth_scopes", "preemptible", b"preemptible", "service_account", b"service_account", "shielded_instance_config", b"shielded_instance_config", "spot", b"spot", "tags", b"tags", "taint", b"taint", "workload_metadata_config", b"workload_metadata_config"]) -> None: ...

global___ContainerClusterXNodePoolXNodeConfig = ContainerClusterXNodePoolXNodeConfig

@typing_extensions.final
class ContainerClusterXNodePoolXUpgradeSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_SURGE_FIELD_NUMBER: builtins.int
    MAX_UNAVAILABLE_FIELD_NUMBER: builtins.int
    max_surge: builtins.float
    max_unavailable: builtins.float
    def __init__(
        self,
        *,
        max_surge: builtins.float = ...,
        max_unavailable: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_surge", b"max_surge", "max_unavailable", b"max_unavailable"]) -> None: ...

global___ContainerClusterXNodePoolXUpgradeSettings = ContainerClusterXNodePoolXUpgradeSettings

@typing_extensions.final
class ContainerClusterXNodePool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INITIAL_NODE_COUNT_FIELD_NUMBER: builtins.int
    INSTANCE_GROUP_URLS_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCE_GROUP_URLS_FIELD_NUMBER: builtins.int
    MAX_PODS_PER_NODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAME_PREFIX_FIELD_NUMBER: builtins.int
    NODE_COUNT_FIELD_NUMBER: builtins.int
    NODE_LOCATIONS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    AUTOSCALING_FIELD_NUMBER: builtins.int
    MANAGEMENT_FIELD_NUMBER: builtins.int
    NODE_CONFIG_FIELD_NUMBER: builtins.int
    UPGRADE_SETTINGS_FIELD_NUMBER: builtins.int
    initial_node_count: builtins.float
    @property
    def instance_group_urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def managed_instance_group_urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_pods_per_node: builtins.float
    name: builtins.str
    name_prefix: builtins.str
    node_count: builtins.float
    @property
    def node_locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    version: builtins.str
    @property
    def autoscaling(self) -> global___ContainerClusterXNodePoolXAutoscaling: ...
    @property
    def management(self) -> global___ContainerClusterXNodePoolXManagement: ...
    @property
    def node_config(self) -> global___ContainerClusterXNodePoolXNodeConfig: ...
    @property
    def upgrade_settings(self) -> global___ContainerClusterXNodePoolXUpgradeSettings: ...
    def __init__(
        self,
        *,
        initial_node_count: builtins.float = ...,
        instance_group_urls: collections.abc.Iterable[builtins.str] | None = ...,
        managed_instance_group_urls: collections.abc.Iterable[builtins.str] | None = ...,
        max_pods_per_node: builtins.float = ...,
        name: builtins.str = ...,
        name_prefix: builtins.str = ...,
        node_count: builtins.float = ...,
        node_locations: collections.abc.Iterable[builtins.str] | None = ...,
        version: builtins.str = ...,
        autoscaling: global___ContainerClusterXNodePoolXAutoscaling | None = ...,
        management: global___ContainerClusterXNodePoolXManagement | None = ...,
        node_config: global___ContainerClusterXNodePoolXNodeConfig | None = ...,
        upgrade_settings: global___ContainerClusterXNodePoolXUpgradeSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscaling", b"autoscaling", "management", b"management", "node_config", b"node_config", "upgrade_settings", b"upgrade_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoscaling", b"autoscaling", "initial_node_count", b"initial_node_count", "instance_group_urls", b"instance_group_urls", "managed_instance_group_urls", b"managed_instance_group_urls", "management", b"management", "max_pods_per_node", b"max_pods_per_node", "name", b"name", "name_prefix", b"name_prefix", "node_config", b"node_config", "node_count", b"node_count", "node_locations", b"node_locations", "upgrade_settings", b"upgrade_settings", "version", b"version"]) -> None: ...

global___ContainerClusterXNodePool = ContainerClusterXNodePool

@typing_extensions.final
class ContainerClusterXNotificationConfigXPubsub(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    topic: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        topic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "topic", b"topic"]) -> None: ...

global___ContainerClusterXNotificationConfigXPubsub = ContainerClusterXNotificationConfigXPubsub

@typing_extensions.final
class ContainerClusterXNotificationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBSUB_FIELD_NUMBER: builtins.int
    @property
    def pubsub(self) -> global___ContainerClusterXNotificationConfigXPubsub: ...
    def __init__(
        self,
        *,
        pubsub: global___ContainerClusterXNotificationConfigXPubsub | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pubsub", b"pubsub"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pubsub", b"pubsub"]) -> None: ...

global___ContainerClusterXNotificationConfig = ContainerClusterXNotificationConfig

@typing_extensions.final
class ContainerClusterXPrivateClusterConfigXMasterGlobalAccessConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ContainerClusterXPrivateClusterConfigXMasterGlobalAccessConfig = ContainerClusterXPrivateClusterConfigXMasterGlobalAccessConfig

@typing_extensions.final
class ContainerClusterXPrivateClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    ENABLE_PRIVATE_NODES_FIELD_NUMBER: builtins.int
    MASTER_IPV4_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    PEERING_NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PUBLIC_ENDPOINT_FIELD_NUMBER: builtins.int
    MASTER_GLOBAL_ACCESS_CONFIG_FIELD_NUMBER: builtins.int
    enable_private_endpoint: builtins.bool
    enable_private_nodes: builtins.bool
    master_ipv4_cidr_block: builtins.str
    peering_name: builtins.str
    private_endpoint: builtins.str
    public_endpoint: builtins.str
    @property
    def master_global_access_config(self) -> global___ContainerClusterXPrivateClusterConfigXMasterGlobalAccessConfig: ...
    def __init__(
        self,
        *,
        enable_private_endpoint: builtins.bool = ...,
        enable_private_nodes: builtins.bool = ...,
        master_ipv4_cidr_block: builtins.str = ...,
        peering_name: builtins.str = ...,
        private_endpoint: builtins.str = ...,
        public_endpoint: builtins.str = ...,
        master_global_access_config: global___ContainerClusterXPrivateClusterConfigXMasterGlobalAccessConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["master_global_access_config", b"master_global_access_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_private_endpoint", b"enable_private_endpoint", "enable_private_nodes", b"enable_private_nodes", "master_global_access_config", b"master_global_access_config", "master_ipv4_cidr_block", b"master_ipv4_cidr_block", "peering_name", b"peering_name", "private_endpoint", b"private_endpoint", "public_endpoint", b"public_endpoint"]) -> None: ...

global___ContainerClusterXPrivateClusterConfig = ContainerClusterXPrivateClusterConfig

@typing_extensions.final
class ContainerClusterXReleaseChannel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_FIELD_NUMBER: builtins.int
    channel: builtins.str
    def __init__(
        self,
        *,
        channel: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel", b"channel"]) -> None: ...

global___ContainerClusterXReleaseChannel = ContainerClusterXReleaseChannel

@typing_extensions.final
class ContainerClusterXResourceUsageExportConfigXBigqueryDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataset_id", b"dataset_id"]) -> None: ...

global___ContainerClusterXResourceUsageExportConfigXBigqueryDestination = ContainerClusterXResourceUsageExportConfigXBigqueryDestination

@typing_extensions.final
class ContainerClusterXResourceUsageExportConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_NETWORK_EGRESS_METERING_FIELD_NUMBER: builtins.int
    ENABLE_RESOURCE_CONSUMPTION_METERING_FIELD_NUMBER: builtins.int
    BIGQUERY_DESTINATION_FIELD_NUMBER: builtins.int
    enable_network_egress_metering: builtins.bool
    enable_resource_consumption_metering: builtins.bool
    @property
    def bigquery_destination(self) -> global___ContainerClusterXResourceUsageExportConfigXBigqueryDestination: ...
    def __init__(
        self,
        *,
        enable_network_egress_metering: builtins.bool = ...,
        enable_resource_consumption_metering: builtins.bool = ...,
        bigquery_destination: global___ContainerClusterXResourceUsageExportConfigXBigqueryDestination | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bigquery_destination", b"bigquery_destination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bigquery_destination", b"bigquery_destination", "enable_network_egress_metering", b"enable_network_egress_metering", "enable_resource_consumption_metering", b"enable_resource_consumption_metering"]) -> None: ...

global___ContainerClusterXResourceUsageExportConfig = ContainerClusterXResourceUsageExportConfig

@typing_extensions.final
class ContainerClusterXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    READ_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    read: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        read: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "read", b"read", "update", b"update"]) -> None: ...

global___ContainerClusterXTimeouts = ContainerClusterXTimeouts

@typing_extensions.final
class ContainerClusterXVerticalPodAutoscaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ContainerClusterXVerticalPodAutoscaling = ContainerClusterXVerticalPodAutoscaling

@typing_extensions.final
class ContainerClusterXWorkloadIdentityConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKLOAD_POOL_FIELD_NUMBER: builtins.int
    workload_pool: builtins.str
    def __init__(
        self,
        *,
        workload_pool: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workload_pool", b"workload_pool"]) -> None: ...

global___ContainerClusterXWorkloadIdentityConfig = ContainerClusterXWorkloadIdentityConfig

@typing_extensions.final
class ContainerCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResourceLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_IPV4_CIDR_FIELD_NUMBER: builtins.int
    DATAPATH_PROVIDER_FIELD_NUMBER: builtins.int
    DEFAULT_MAX_PODS_PER_NODE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLE_AUTOPILOT_FIELD_NUMBER: builtins.int
    ENABLE_BINARY_AUTHORIZATION_FIELD_NUMBER: builtins.int
    ENABLE_INTRANODE_VISIBILITY_FIELD_NUMBER: builtins.int
    ENABLE_KUBERNETES_ALPHA_FIELD_NUMBER: builtins.int
    ENABLE_LEGACY_ABAC_FIELD_NUMBER: builtins.int
    ENABLE_SHIELDED_NODES_FIELD_NUMBER: builtins.int
    ENABLE_TPU_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INITIAL_NODE_COUNT_FIELD_NUMBER: builtins.int
    LABEL_FINGERPRINT_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    LOGGING_SERVICE_FIELD_NUMBER: builtins.int
    MASTER_VERSION_FIELD_NUMBER: builtins.int
    MIN_MASTER_VERSION_FIELD_NUMBER: builtins.int
    MONITORING_SERVICE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NETWORKING_MODE_FIELD_NUMBER: builtins.int
    NODE_LOCATIONS_FIELD_NUMBER: builtins.int
    NODE_VERSION_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    PRIVATE_IPV6_GOOGLE_ACCESS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REMOVE_DEFAULT_NODE_POOL_FIELD_NUMBER: builtins.int
    RESOURCE_LABELS_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SERVICES_IPV4_CIDR_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    TPU_IPV4_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    ADDONS_CONFIG_FIELD_NUMBER: builtins.int
    AUTHENTICATOR_GROUPS_CONFIG_FIELD_NUMBER: builtins.int
    BINARY_AUTHORIZATION_FIELD_NUMBER: builtins.int
    CLUSTER_AUTOSCALING_FIELD_NUMBER: builtins.int
    CONFIDENTIAL_NODES_FIELD_NUMBER: builtins.int
    DATABASE_ENCRYPTION_FIELD_NUMBER: builtins.int
    DEFAULT_SNAT_STATUS_FIELD_NUMBER: builtins.int
    DNS_CONFIG_FIELD_NUMBER: builtins.int
    IP_ALLOCATION_POLICY_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    MAINTENANCE_POLICY_FIELD_NUMBER: builtins.int
    MASTER_AUTH_FIELD_NUMBER: builtins.int
    MASTER_AUTHORIZED_NETWORKS_CONFIG_FIELD_NUMBER: builtins.int
    MONITORING_CONFIG_FIELD_NUMBER: builtins.int
    NETWORK_POLICY_FIELD_NUMBER: builtins.int
    NODE_CONFIG_FIELD_NUMBER: builtins.int
    NODE_POOL_FIELD_NUMBER: builtins.int
    NOTIFICATION_CONFIG_FIELD_NUMBER: builtins.int
    PRIVATE_CLUSTER_CONFIG_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    RESOURCE_USAGE_EXPORT_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VERTICAL_POD_AUTOSCALING_FIELD_NUMBER: builtins.int
    WORKLOAD_IDENTITY_CONFIG_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cluster_ipv4_cidr: builtins.str
    datapath_provider: builtins.str
    default_max_pods_per_node: builtins.float
    description: builtins.str
    enable_autopilot: builtins.bool
    enable_binary_authorization: builtins.bool
    enable_intranode_visibility: builtins.bool
    enable_kubernetes_alpha: builtins.bool
    enable_legacy_abac: builtins.bool
    enable_shielded_nodes: builtins.bool
    enable_tpu: builtins.bool
    endpoint: builtins.str
    id: builtins.str
    initial_node_count: builtins.float
    label_fingerprint: builtins.str
    location: builtins.str
    logging_service: builtins.str
    master_version: builtins.str
    min_master_version: builtins.str
    monitoring_service: builtins.str
    name: builtins.str
    network: builtins.str
    networking_mode: builtins.str
    @property
    def node_locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    node_version: builtins.str
    operation: builtins.str
    private_ipv6_google_access: builtins.str
    project: builtins.str
    remove_default_node_pool: builtins.bool
    @property
    def resource_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    self_link: builtins.str
    services_ipv4_cidr: builtins.str
    subnetwork: builtins.str
    tpu_ipv4_cidr_block: builtins.str
    @property
    def addons_config(self) -> global___ContainerClusterXAddonsConfig: ...
    @property
    def authenticator_groups_config(self) -> global___ContainerClusterXAuthenticatorGroupsConfig: ...
    @property
    def binary_authorization(self) -> global___ContainerClusterXBinaryAuthorization: ...
    @property
    def cluster_autoscaling(self) -> global___ContainerClusterXClusterAutoscaling: ...
    @property
    def confidential_nodes(self) -> global___ContainerClusterXConfidentialNodes: ...
    @property
    def database_encryption(self) -> global___ContainerClusterXDatabaseEncryption: ...
    @property
    def default_snat_status(self) -> global___ContainerClusterXDefaultSnatStatus: ...
    @property
    def dns_config(self) -> global___ContainerClusterXDnsConfig: ...
    @property
    def ip_allocation_policy(self) -> global___ContainerClusterXIpAllocationPolicy: ...
    @property
    def logging_config(self) -> global___ContainerClusterXLoggingConfig: ...
    @property
    def maintenance_policy(self) -> global___ContainerClusterXMaintenancePolicy: ...
    @property
    def master_auth(self) -> global___ContainerClusterXMasterAuth: ...
    @property
    def master_authorized_networks_config(self) -> global___ContainerClusterXMasterAuthorizedNetworksConfig: ...
    @property
    def monitoring_config(self) -> global___ContainerClusterXMonitoringConfig: ...
    @property
    def network_policy(self) -> global___ContainerClusterXNetworkPolicy: ...
    @property
    def node_config(self) -> global___ContainerClusterXNodeConfig: ...
    @property
    def node_pool(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerClusterXNodePool]: ...
    @property
    def notification_config(self) -> global___ContainerClusterXNotificationConfig: ...
    @property
    def private_cluster_config(self) -> global___ContainerClusterXPrivateClusterConfig: ...
    @property
    def release_channel(self) -> global___ContainerClusterXReleaseChannel: ...
    @property
    def resource_usage_export_config(self) -> global___ContainerClusterXResourceUsageExportConfig: ...
    @property
    def timeouts(self) -> global___ContainerClusterXTimeouts: ...
    @property
    def vertical_pod_autoscaling(self) -> global___ContainerClusterXVerticalPodAutoscaling: ...
    @property
    def workload_identity_config(self) -> global___ContainerClusterXWorkloadIdentityConfig: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cluster_ipv4_cidr: builtins.str = ...,
        datapath_provider: builtins.str = ...,
        default_max_pods_per_node: builtins.float = ...,
        description: builtins.str = ...,
        enable_autopilot: builtins.bool = ...,
        enable_binary_authorization: builtins.bool = ...,
        enable_intranode_visibility: builtins.bool = ...,
        enable_kubernetes_alpha: builtins.bool = ...,
        enable_legacy_abac: builtins.bool = ...,
        enable_shielded_nodes: builtins.bool = ...,
        enable_tpu: builtins.bool = ...,
        endpoint: builtins.str = ...,
        id: builtins.str = ...,
        initial_node_count: builtins.float = ...,
        label_fingerprint: builtins.str = ...,
        location: builtins.str = ...,
        logging_service: builtins.str = ...,
        master_version: builtins.str = ...,
        min_master_version: builtins.str = ...,
        monitoring_service: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        networking_mode: builtins.str = ...,
        node_locations: collections.abc.Iterable[builtins.str] | None = ...,
        node_version: builtins.str = ...,
        operation: builtins.str = ...,
        private_ipv6_google_access: builtins.str = ...,
        project: builtins.str = ...,
        remove_default_node_pool: builtins.bool = ...,
        resource_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        self_link: builtins.str = ...,
        services_ipv4_cidr: builtins.str = ...,
        subnetwork: builtins.str = ...,
        tpu_ipv4_cidr_block: builtins.str = ...,
        addons_config: global___ContainerClusterXAddonsConfig | None = ...,
        authenticator_groups_config: global___ContainerClusterXAuthenticatorGroupsConfig | None = ...,
        binary_authorization: global___ContainerClusterXBinaryAuthorization | None = ...,
        cluster_autoscaling: global___ContainerClusterXClusterAutoscaling | None = ...,
        confidential_nodes: global___ContainerClusterXConfidentialNodes | None = ...,
        database_encryption: global___ContainerClusterXDatabaseEncryption | None = ...,
        default_snat_status: global___ContainerClusterXDefaultSnatStatus | None = ...,
        dns_config: global___ContainerClusterXDnsConfig | None = ...,
        ip_allocation_policy: global___ContainerClusterXIpAllocationPolicy | None = ...,
        logging_config: global___ContainerClusterXLoggingConfig | None = ...,
        maintenance_policy: global___ContainerClusterXMaintenancePolicy | None = ...,
        master_auth: global___ContainerClusterXMasterAuth | None = ...,
        master_authorized_networks_config: global___ContainerClusterXMasterAuthorizedNetworksConfig | None = ...,
        monitoring_config: global___ContainerClusterXMonitoringConfig | None = ...,
        network_policy: global___ContainerClusterXNetworkPolicy | None = ...,
        node_config: global___ContainerClusterXNodeConfig | None = ...,
        node_pool: collections.abc.Iterable[global___ContainerClusterXNodePool] | None = ...,
        notification_config: global___ContainerClusterXNotificationConfig | None = ...,
        private_cluster_config: global___ContainerClusterXPrivateClusterConfig | None = ...,
        release_channel: global___ContainerClusterXReleaseChannel | None = ...,
        resource_usage_export_config: global___ContainerClusterXResourceUsageExportConfig | None = ...,
        timeouts: global___ContainerClusterXTimeouts | None = ...,
        vertical_pod_autoscaling: global___ContainerClusterXVerticalPodAutoscaling | None = ...,
        workload_identity_config: global___ContainerClusterXWorkloadIdentityConfig | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["addons_config", b"addons_config", "authenticator_groups_config", b"authenticator_groups_config", "binary_authorization", b"binary_authorization", "cluster_autoscaling", b"cluster_autoscaling", "confidential_nodes", b"confidential_nodes", "database_encryption", b"database_encryption", "default_snat_status", b"default_snat_status", "dns_config", b"dns_config", "ip_allocation_policy", b"ip_allocation_policy", "logging_config", b"logging_config", "maintenance_policy", b"maintenance_policy", "master_auth", b"master_auth", "master_authorized_networks_config", b"master_authorized_networks_config", "monitoring_config", b"monitoring_config", "network_policy", b"network_policy", "node_config", b"node_config", "notification_config", b"notification_config", "private_cluster_config", b"private_cluster_config", "release_channel", b"release_channel", "resource_info", b"resource_info", "resource_usage_export_config", b"resource_usage_export_config", "timeouts", b"timeouts", "vertical_pod_autoscaling", b"vertical_pod_autoscaling", "workload_identity_config", b"workload_identity_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["addons_config", b"addons_config", "authenticator_groups_config", b"authenticator_groups_config", "binary_authorization", b"binary_authorization", "cluster_autoscaling", b"cluster_autoscaling", "cluster_ipv4_cidr", b"cluster_ipv4_cidr", "confidential_nodes", b"confidential_nodes", "database_encryption", b"database_encryption", "datapath_provider", b"datapath_provider", "default_max_pods_per_node", b"default_max_pods_per_node", "default_snat_status", b"default_snat_status", "description", b"description", "dns_config", b"dns_config", "enable_autopilot", b"enable_autopilot", "enable_binary_authorization", b"enable_binary_authorization", "enable_intranode_visibility", b"enable_intranode_visibility", "enable_kubernetes_alpha", b"enable_kubernetes_alpha", "enable_legacy_abac", b"enable_legacy_abac", "enable_shielded_nodes", b"enable_shielded_nodes", "enable_tpu", b"enable_tpu", "endpoint", b"endpoint", "id", b"id", "initial_node_count", b"initial_node_count", "ip_allocation_policy", b"ip_allocation_policy", "label_fingerprint", b"label_fingerprint", "location", b"location", "logging_config", b"logging_config", "logging_service", b"logging_service", "maintenance_policy", b"maintenance_policy", "master_auth", b"master_auth", "master_authorized_networks_config", b"master_authorized_networks_config", "master_version", b"master_version", "min_master_version", b"min_master_version", "monitoring_config", b"monitoring_config", "monitoring_service", b"monitoring_service", "name", b"name", "network", b"network", "network_policy", b"network_policy", "networking_mode", b"networking_mode", "node_config", b"node_config", "node_locations", b"node_locations", "node_pool", b"node_pool", "node_version", b"node_version", "notification_config", b"notification_config", "operation", b"operation", "private_cluster_config", b"private_cluster_config", "private_ipv6_google_access", b"private_ipv6_google_access", "project", b"project", "release_channel", b"release_channel", "remove_default_node_pool", b"remove_default_node_pool", "resource_info", b"resource_info", "resource_labels", b"resource_labels", "resource_usage_export_config", b"resource_usage_export_config", "self_link", b"self_link", "services_ipv4_cidr", b"services_ipv4_cidr", "subnetwork", b"subnetwork", "timeouts", b"timeouts", "tpu_ipv4_cidr_block", b"tpu_ipv4_cidr_block", "vertical_pod_autoscaling", b"vertical_pod_autoscaling", "workload_identity_config", b"workload_identity_config"]) -> None: ...

global___ContainerCluster = ContainerCluster

@typing_extensions.final
class ContainerNodePoolXAutoscaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_NODE_COUNT_FIELD_NUMBER: builtins.int
    MIN_NODE_COUNT_FIELD_NUMBER: builtins.int
    max_node_count: builtins.float
    min_node_count: builtins.float
    def __init__(
        self,
        *,
        max_node_count: builtins.float = ...,
        min_node_count: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_node_count", b"max_node_count", "min_node_count", b"min_node_count"]) -> None: ...

global___ContainerNodePoolXAutoscaling = ContainerNodePoolXAutoscaling

@typing_extensions.final
class ContainerNodePoolXManagement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_REPAIR_FIELD_NUMBER: builtins.int
    AUTO_UPGRADE_FIELD_NUMBER: builtins.int
    auto_repair: builtins.bool
    auto_upgrade: builtins.bool
    def __init__(
        self,
        *,
        auto_repair: builtins.bool = ...,
        auto_upgrade: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_repair", b"auto_repair", "auto_upgrade", b"auto_upgrade"]) -> None: ...

global___ContainerNodePoolXManagement = ContainerNodePoolXManagement

@typing_extensions.final
class ContainerNodePoolXNodeConfigXGcfsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ContainerNodePoolXNodeConfigXGcfsConfig = ContainerNodePoolXNodeConfigXGcfsConfig

@typing_extensions.final
class ContainerNodePoolXNodeConfigXGvnic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___ContainerNodePoolXNodeConfigXGvnic = ContainerNodePoolXNodeConfigXGvnic

@typing_extensions.final
class ContainerNodePoolXNodeConfigXShieldedInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_INTEGRITY_MONITORING_FIELD_NUMBER: builtins.int
    ENABLE_SECURE_BOOT_FIELD_NUMBER: builtins.int
    enable_integrity_monitoring: builtins.bool
    enable_secure_boot: builtins.bool
    def __init__(
        self,
        *,
        enable_integrity_monitoring: builtins.bool = ...,
        enable_secure_boot: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_integrity_monitoring", b"enable_integrity_monitoring", "enable_secure_boot", b"enable_secure_boot"]) -> None: ...

global___ContainerNodePoolXNodeConfigXShieldedInstanceConfig = ContainerNodePoolXNodeConfigXShieldedInstanceConfig

@typing_extensions.final
class ContainerNodePoolXNodeConfigXWorkloadMetadataConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODE_FIELD_NUMBER: builtins.int
    mode: builtins.str
    def __init__(
        self,
        *,
        mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mode", b"mode"]) -> None: ...

global___ContainerNodePoolXNodeConfigXWorkloadMetadataConfig = ContainerNodePoolXNodeConfigXWorkloadMetadataConfig

@typing_extensions.final
class ContainerNodePoolXNodeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class GuestAcceleratorEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TaintEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BOOT_DISK_KMS_KEY_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    DISK_TYPE_FIELD_NUMBER: builtins.int
    GUEST_ACCELERATOR_FIELD_NUMBER: builtins.int
    IMAGE_TYPE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCAL_SSD_COUNT_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    NODE_GROUP_FIELD_NUMBER: builtins.int
    OAUTH_SCOPES_FIELD_NUMBER: builtins.int
    PREEMPTIBLE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SPOT_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TAINT_FIELD_NUMBER: builtins.int
    GCFS_CONFIG_FIELD_NUMBER: builtins.int
    GVNIC_FIELD_NUMBER: builtins.int
    SHIELDED_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    WORKLOAD_METADATA_CONFIG_FIELD_NUMBER: builtins.int
    boot_disk_kms_key: builtins.str
    disk_size_gb: builtins.float
    disk_type: builtins.str
    @property
    def guest_accelerator(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    image_type: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    local_ssd_count: builtins.float
    machine_type: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    min_cpu_platform: builtins.str
    node_group: builtins.str
    @property
    def oauth_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    preemptible: builtins.bool
    service_account: builtins.str
    spot: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def taint(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def gcfs_config(self) -> global___ContainerNodePoolXNodeConfigXGcfsConfig: ...
    @property
    def gvnic(self) -> global___ContainerNodePoolXNodeConfigXGvnic: ...
    @property
    def shielded_instance_config(self) -> global___ContainerNodePoolXNodeConfigXShieldedInstanceConfig: ...
    @property
    def workload_metadata_config(self) -> global___ContainerNodePoolXNodeConfigXWorkloadMetadataConfig: ...
    def __init__(
        self,
        *,
        boot_disk_kms_key: builtins.str = ...,
        disk_size_gb: builtins.float = ...,
        disk_type: builtins.str = ...,
        guest_accelerator: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        image_type: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        local_ssd_count: builtins.float = ...,
        machine_type: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        min_cpu_platform: builtins.str = ...,
        node_group: builtins.str = ...,
        oauth_scopes: collections.abc.Iterable[builtins.str] | None = ...,
        preemptible: builtins.bool = ...,
        service_account: builtins.str = ...,
        spot: builtins.bool = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        taint: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        gcfs_config: global___ContainerNodePoolXNodeConfigXGcfsConfig | None = ...,
        gvnic: global___ContainerNodePoolXNodeConfigXGvnic | None = ...,
        shielded_instance_config: global___ContainerNodePoolXNodeConfigXShieldedInstanceConfig | None = ...,
        workload_metadata_config: global___ContainerNodePoolXNodeConfigXWorkloadMetadataConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gcfs_config", b"gcfs_config", "gvnic", b"gvnic", "shielded_instance_config", b"shielded_instance_config", "workload_metadata_config", b"workload_metadata_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["boot_disk_kms_key", b"boot_disk_kms_key", "disk_size_gb", b"disk_size_gb", "disk_type", b"disk_type", "gcfs_config", b"gcfs_config", "guest_accelerator", b"guest_accelerator", "gvnic", b"gvnic", "image_type", b"image_type", "labels", b"labels", "local_ssd_count", b"local_ssd_count", "machine_type", b"machine_type", "metadata", b"metadata", "min_cpu_platform", b"min_cpu_platform", "node_group", b"node_group", "oauth_scopes", b"oauth_scopes", "preemptible", b"preemptible", "service_account", b"service_account", "shielded_instance_config", b"shielded_instance_config", "spot", b"spot", "tags", b"tags", "taint", b"taint", "workload_metadata_config", b"workload_metadata_config"]) -> None: ...

global___ContainerNodePoolXNodeConfig = ContainerNodePoolXNodeConfig

@typing_extensions.final
class ContainerNodePoolXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ContainerNodePoolXTimeouts = ContainerNodePoolXTimeouts

@typing_extensions.final
class ContainerNodePoolXUpgradeSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_SURGE_FIELD_NUMBER: builtins.int
    MAX_UNAVAILABLE_FIELD_NUMBER: builtins.int
    max_surge: builtins.float
    max_unavailable: builtins.float
    def __init__(
        self,
        *,
        max_surge: builtins.float = ...,
        max_unavailable: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_surge", b"max_surge", "max_unavailable", b"max_unavailable"]) -> None: ...

global___ContainerNodePoolXUpgradeSettings = ContainerNodePoolXUpgradeSettings

@typing_extensions.final
class ContainerNodePool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INITIAL_NODE_COUNT_FIELD_NUMBER: builtins.int
    INSTANCE_GROUP_URLS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MANAGED_INSTANCE_GROUP_URLS_FIELD_NUMBER: builtins.int
    MAX_PODS_PER_NODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAME_PREFIX_FIELD_NUMBER: builtins.int
    NODE_COUNT_FIELD_NUMBER: builtins.int
    NODE_LOCATIONS_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    AUTOSCALING_FIELD_NUMBER: builtins.int
    MANAGEMENT_FIELD_NUMBER: builtins.int
    NODE_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    UPGRADE_SETTINGS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cluster: builtins.str
    id: builtins.str
    initial_node_count: builtins.float
    @property
    def instance_group_urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    location: builtins.str
    @property
    def managed_instance_group_urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_pods_per_node: builtins.float
    name: builtins.str
    name_prefix: builtins.str
    node_count: builtins.float
    @property
    def node_locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    operation: builtins.str
    project: builtins.str
    version: builtins.str
    @property
    def autoscaling(self) -> global___ContainerNodePoolXAutoscaling: ...
    @property
    def management(self) -> global___ContainerNodePoolXManagement: ...
    @property
    def node_config(self) -> global___ContainerNodePoolXNodeConfig: ...
    @property
    def timeouts(self) -> global___ContainerNodePoolXTimeouts: ...
    @property
    def upgrade_settings(self) -> global___ContainerNodePoolXUpgradeSettings: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cluster: builtins.str = ...,
        id: builtins.str = ...,
        initial_node_count: builtins.float = ...,
        instance_group_urls: collections.abc.Iterable[builtins.str] | None = ...,
        location: builtins.str = ...,
        managed_instance_group_urls: collections.abc.Iterable[builtins.str] | None = ...,
        max_pods_per_node: builtins.float = ...,
        name: builtins.str = ...,
        name_prefix: builtins.str = ...,
        node_count: builtins.float = ...,
        node_locations: collections.abc.Iterable[builtins.str] | None = ...,
        operation: builtins.str = ...,
        project: builtins.str = ...,
        version: builtins.str = ...,
        autoscaling: global___ContainerNodePoolXAutoscaling | None = ...,
        management: global___ContainerNodePoolXManagement | None = ...,
        node_config: global___ContainerNodePoolXNodeConfig | None = ...,
        timeouts: global___ContainerNodePoolXTimeouts | None = ...,
        upgrade_settings: global___ContainerNodePoolXUpgradeSettings | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscaling", b"autoscaling", "management", b"management", "node_config", b"node_config", "resource_info", b"resource_info", "timeouts", b"timeouts", "upgrade_settings", b"upgrade_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoscaling", b"autoscaling", "cluster", b"cluster", "id", b"id", "initial_node_count", b"initial_node_count", "instance_group_urls", b"instance_group_urls", "location", b"location", "managed_instance_group_urls", b"managed_instance_group_urls", "management", b"management", "max_pods_per_node", b"max_pods_per_node", "name", b"name", "name_prefix", b"name_prefix", "node_config", b"node_config", "node_count", b"node_count", "node_locations", b"node_locations", "operation", b"operation", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "upgrade_settings", b"upgrade_settings", "version", b"version"]) -> None: ...

global___ContainerNodePool = ContainerNodePool

@typing_extensions.final
class ContainerRegistry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_SELF_LINK_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket_self_link: builtins.str
    id: builtins.str
    location: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket_self_link: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_self_link", b"bucket_self_link", "id", b"id", "location", b"location", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___ContainerRegistry = ContainerRegistry
